@@ -3,9 +3,7 @@ from pip._vendor.pkg_resources import get_distribution
 
 from contrast.agent.assess.string_tracker import StringTracker
 from contrast.utils.context_tracker import ContextTracker
-from contrast.agent.assess.utils import (
-    get_properties,
-)  # noqa: provides a cleaner import
+
 from contrast.extern.six import PY2
 
 
@@ -16,7 +14,11 @@ CS__CONTEXT_TRACKER = ContextTracker()
 STRING_TRACKER = StringTracker()
 
 
+# --- import aliases ---
+
+from contrast.agent.assess.utils import get_properties  # noqa
+
 if PY2:
     from contrast.extern import pathlib2 as pathlib
 else:
-    import pathlib
+    import pathlib  # noqa
