@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.utils.assess.duck_utils import safe_obj_length
+from contrast.utils.assess.duck_utils import len_or_zero
 
 
 class Preshift(object):
@@ -11,7 +11,7 @@ class Preshift(object):
 
     def __init__(self, self_obj, call_args, call_kwargs):
         self.obj = self_obj
-        self.obj_length = safe_obj_length(self_obj)
+        self.obj_length = len_or_zero(self_obj)
         self.args = call_args or []
         self.kwargs = call_kwargs or {}
 
