@@ -21,7 +21,7 @@ from contrast.agent.assess.policy.preshift import Preshift
 from contrast.agent.assess.utils import (
     copy_tags_to_offset,
     copy_events,
-    cs__copy_from,
+    copy_from,
     cs__tracked,
     get_properties,
     track_string,
@@ -30,11 +30,11 @@ from contrast.utils.assess.duck_utils import (
     is_filelike,
     is_iterable,
     safe_iterator,
-    safe_obj_length,
+    len_or_zero,
 )
 from contrast.agent.settings_state import SettingsState
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -66,7 +66,7 @@ def is_target_valid_length(target, action):
     if action in IGNORE_LENGTH_ACTIONS:
         return True
 
-    return safe_obj_length(target) > 0
+    return len_or_zero(target) > 0
 
 
 def track_copy_without_new_event(target, self_obj):
@@ -84,7 +84,7 @@ def track_copy_without_new_event(target, self_obj):
     """
     if cs__tracked(self_obj):
         track_string(target)
-        cs__copy_from(target, self_obj, 0, set())
+        copy_from(target, self_obj, 0, set())
 
 
 STREAM_SOURCES = ["read", "read1", "readline", "readlines", "getvalue"]
