@@ -5,10 +5,10 @@ from __future__ import division
 import math
 
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
-from contrast.agent.assess.utils import cs__copy_from
+from contrast.agent.assess.utils import copy_from
 
 
 class CenterPropagator(BasePropagator):
     def _propagate(self):
         start_index = math.ceil((len(self.target) - len(self.first_source)) / 2)
-        cs__copy_from(self.target, self.first_source, start_index, self.node.untags)
+        copy_from(self.target, self.first_source, start_index, self.node.untags)
