@@ -2,7 +2,7 @@
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
-from contrast.agent.assess.utils import cs__copy_from
+from contrast.agent.assess.utils import copy_from
 
 
 class PrependPropagator(BasePropagator):
@@ -13,6 +13,6 @@ class PrependPropagator(BasePropagator):
             original_start_index = 0
 
         # find original in the target, copy tags to the new position in target
-        cs__copy_from(
+        copy_from(
             self.target, self.first_source, original_start_index, self.node.untags
         )
