@@ -3,7 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern import six
 
-from contrast.agent.assess.utils import cs__splat_tags, cs__copy_from
+from contrast.agent.assess.utils import cs__splat_tags, copy_from
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
 
 
@@ -30,7 +30,7 @@ class ReprPropagator(BasePropagator):
             offset = self.target.rfind(string)
 
         if offset >= 0:
-            cs__copy_from(self.target, self.first_source, offset, self.node.untags)
+            copy_from(self.target, self.first_source, offset, self.node.untags)
             return
 
         # If it's not, then just splat to account for encoding, etc.
