@@ -22,7 +22,7 @@ from contrast.utils.decorators import fail_safely
 from contrast.utils.string_utils import truncated_signature
 from contrast.agent.settings_state import SettingsState
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
