@@ -4,7 +4,7 @@
 from contrast.agent.settings_state import SettingsState
 from contrast.utils.digest_utils import Digest
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
