@@ -11,7 +11,7 @@ from contrast.utils.decorators import fail_safely
 from contrast.utils.stdlib_modules import is_stdlib_module
 from .code_parser_mixin import CodeParserMixin
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
