@@ -6,13 +6,12 @@ from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.assess.rules.base_rule import BaseRule
 from contrast.agent.assess.utils import get_properties
-from contrast.agent.settings_state import SettingsState
 from contrast.api import Finding
 from contrast.utils.decorators import cached_property
 from contrast.utils.string_utils import equals_ignore_case
 
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -154,9 +153,6 @@ class TriggerRule(BaseRule):
 
         context.activity.findings.extend([finding_msg])
 
-        settings = SettingsState()
-        context.activity.finding_tags = settings.config.get("assess.tags", "")
-
         logger.debug(
             "Trigger %s detected: %s triggered %s",
             node.name,
