@@ -48,38 +48,41 @@ def copy_events(target_props, source_props):
         target_props.events.append(event)
 
 
-def cs__copy_from(value, self_obj, shift=0, skip_tags=None):
-    if self_obj is value:
+def copy_from(to_obj, from_obj, shift=0, skip_tags=None):
+    """Copy events and tags from from_obj to to_obj"""
+    if from_obj is to_obj:
         return
 
-    if not cs__tracked(self_obj):
+    if not cs__tracked(from_obj):
         return
 
-    obj_props = get_properties(self_obj)
-    self_props = get_properties(value)
+    from_props = get_properties(from_obj)
 
-    if obj_props == self_props:
-        cs__reset_properties(value)
+    # we assume to_obj has already been tracked and has properties
+    to_props = get_properties(to_obj)
 
-    copy_events(self_props, obj_props)
+    if from_props == to_props:
+        cs__reset_properties(to_obj)
 
-    for key in obj_props.tag_keys():
+    copy_events(to_props, from_props)
+
+    for key in from_props.tag_keys():
         if skip_tags and key in skip_tags:
             continue
 
         new_tags = []
 
-        obj_props_tags = obj_props.fetch_tags(key)
+        from_props_tags = from_props.fetch_tags(key)
 
-        for tag in obj_props_tags:
+        for tag in from_props_tags:
             new_tags.append(tag.copy_modified(shift))
 
-        existing_tags = self_props.fetch_tags(key)
+        existing_tags = to_props.fetch_tags(key)
 
         if existing_tags:
             existing_tags.extend(new_tags)
         else:
-            self_props.set_tag(key, new_tags)
+            to_props.set_tag(key, new_tags)
 
 
 def cs__splat_tags(value, ret, source=None):
