@@ -36,7 +36,7 @@ FILE_NODE_DICT = {
     "type": "PARAMETER",
 }
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
