@@ -23,7 +23,7 @@ from contrast.utils.exceptions.contrast_service_exception import (
 )
 from contrast.utils.exceptions.disable_agent_exception import DisableAgentException
 from contrast.utils.exceptions.security_exception import SecurityException
-from contrast.utils.library_reader import LibraryReader
+from contrast.utils.library_reader.library_reader import LibraryReader
 from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_logger
 
 # initialize a basic logger until config is parsed
@@ -80,12 +80,15 @@ class BaseMiddleware(RoutesMixin):
             return
 
         setup_agent_logger(self.settings.config)
-        self.log_environment()
+        self.settings.config.log_config()
 
         if not self.initialize_service_client():
             logger.error("Unable to initialize Contrast Agent.")
             return
 
+        # This call must happen after initializing SR so we have all data to log
+        self.log_environment()
+
         self.initialize_libraries()
 
         if (
@@ -165,8 +168,11 @@ class BaseMiddleware(RoutesMixin):
         if not self.settings.is_analyze_libs_enabled():
             return
 
-        # Similar to the heartbeat thread, settings is required in order to send messages to SR
-        self.library_reader = LibraryReader(self.settings.library_tags, self.settings)
+        # Passing callback to send message due to a circular import issue, and a deadlock
+        # occurring if something is imported inside of a function running in this thread
+        self.library_reader = LibraryReader(
+            send_message_func=service_client.send_messages
+        )
         self.library_reader.start_library_analysis_thread()
 
     def is_agent_enabled(self):
@@ -244,62 +250,6 @@ class BaseMiddleware(RoutesMixin):
 
         return final_messages
 
-    def update_libraries(self, context):
-        """
-        After the app code is executed and a response is received, check for
-        newly loaded modules and determine if to update library information.
-        """
-
-        # TODO: PYT-807 will address reporting files loaded after our catch phase.
-        # Disabled so it doesn't throw off the results sent up in ApplicationUpdate
-
-        # from contrast.utils.patch_utils import get_loaded_modules
-        # from contrast.utils import inventory_utils
-
-        # if not self.settings.is_analyze_libs_enabled():
-        #     return
-
-        # if self.settings.unused_libraries:
-        #     sys_modules = get_loaded_modules().values()
-
-        #     if len(sys_modules) != self.settings.sys_module_count:
-        #         self.settings.sys_module_count = len(sys_modules)
-        #         self._get_updated_file_count(self.settings.libraries, sys_modules)
-        #         # should we be updating info for unused libraries, and if so
-        #         # should we move unused libraries that now have used_count > 0 to used libraries?
-        #         self._get_updated_file_count(
-        #             self.settings.unused_libraries, sys_modules
-        #         )
-
-        # inventory_utils.append_libraries(context.activity, self.settings)
-        pass
-
-    def _get_updated_file_count(self, libraries, sys_modules):
-        """
-        Check if there are any new files in libraries that were added to the sys path
-        """
-
-        for library in libraries:
-            new_used_count = self._search_modules_for_library(
-                library.file_path, sys_modules
-            )
-            library.used_class_count = new_used_count
-
-    def _search_modules_for_library(self, library_name, sys_modules):
-        """
-        Searches every module to see if it is associated with the current package being looked at
-        If the package hasn't been found, it gets the metadata for the package, otherwise it
-        just keeps updating used file count
-        :param sys_modules: current loaded sys modules
-        :param library_name: name of the library
-        :return: The new used file count for this library
-        """
-        all_lib_modules = [
-            x for x in sys_modules if (x.__name__ + ".").startswith(library_name)
-        ]
-
-        return len(set(all_lib_modules))
-
     def generate_security_exception_response(self):
         """
         Generate a response to be returned in the case of a SecurityException.
@@ -533,13 +483,11 @@ class BaseMiddleware(RoutesMixin):
                 raise SecurityException(None, message=msg)
 
     def log_start_request_analysis(self, request_path):
-        logger.debug("Contrast Agent analyzing request: %s", request_path)
+        logger.debug("Beginning request analysis", request_path=request_path)
 
     def log_end_request_analysis(self, request_path):
         logger.debug(
-            "Contrast Agent finished analyzing request: %s \n\n%s\n",
-            request_path,
-            self.LOGS_SEPARATOR,
+            "Ending request analysis", request_path=request_path,
         )
 
     def log_initialize(self):
