@@ -9,25 +9,12 @@ from contrast.agent.middlewares.route_coverage.falcon_routes import (
 )
 from contrast.utils.decorators import fail_safely, fail_quietly
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
 
 class FalconMiddleware(WSGIMiddleware):
-    """
-    Falcon apps should use this middleware like so:
-
-    ```
-    from contrast.agent.middlewares.falcon_middleware import FalconMiddleware as ContrastMiddleware
-
-    contrast = ContrastMiddleware()
-    app = falcon.API(middleware=[contrast])
-    contrast.register_app(app)
-    ```
-    Calling register_app is required. See the method for why.
-    """
-
     def __init__(self, app):
         # Since Falcon is WSGI-based, there is no way to retrieve the app name.
         # Use common config to define an app name.
