@@ -14,7 +14,7 @@ from contrast.agent.middlewares.route_coverage.coverage_utils import (
 from contrast.agent.settings_state import SettingsState
 from contrast.extern.functools_lru_cache import lru_cache
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -145,17 +145,25 @@ def create_django_routes():
     return create_routes(url_patterns)
 
 
-def build_django_route(pattern_or_resolver, method_arg_names=None):
-    if hasattr(pattern_or_resolver, "lookup_str"):
-        route = pattern_or_resolver.lookup_str
-    elif hasattr(pattern_or_resolver, "callback"):
-        cb = pattern_or_resolver.callback
-        route = cb.__module__ + "." + cb.__name__
+def _function_loc(func):
+    """Return the function's module and name"""
+    return "{0.__module__}.{0.__name__}".format(func)
+
+
+def build_django_route(obj, method_arg_names=None):
+    if hasattr(obj, "lookup_str"):
+        route = obj.lookup_str
+    elif hasattr(obj, "callback"):
+        cb = obj.callback
+        route = _function_loc(cb)
+    elif callable(obj):
+        route = _function_loc(obj)
     else:
+        logger.debug("WARNING: can't build django route for object type %s", type(obj))
         return ""
 
     if method_arg_names is None:
-        method_arg_names = CoverageUtils.build_args_from_function(pattern_or_resolver)
+        method_arg_names = CoverageUtils.build_args_from_function(obj)
 
     route += method_arg_names
     return route
