@@ -9,7 +9,7 @@ from pyramid.interfaces import IView, IViewClassifier, IRouteRequest, IRoutesMap
 from pyramid.request import route_request_iface
 from zope.interface import Interface
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
