@@ -5,7 +5,7 @@ from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUti
 from contrast.api import Finding
 
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
