@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -13,6 +13,7 @@ from contrast.patches import (
     cs_str as cs_str_patches,
     register_assess_patches,
     register_common_patches,
+    register_library_patches,
 )
 from contrast.utils.namespace import Namespace
 from contrast.utils.patch_utils import repatch_imported_modules
@@ -69,6 +70,9 @@ def disable_assess_patches():
 def _enable_patches():
     settings = SettingsState()
 
+    if settings.is_analyze_libs_enabled():
+        register_library_patches()
+
     if settings.is_protect_enabled():
         register_common_patches()
 
