@@ -32,7 +32,7 @@ from contrast.utils.patch_utils import (
 )
 
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
