@@ -28,7 +28,7 @@ from contrast.agent.assess.rules.triggers import (
 from contrast.utils.singleton import Singleton
 from contrast.utils.decorators import fail_safely
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
