@@ -7,7 +7,7 @@ from contrast.extern.six import PY2
 from contrast.assess_extensions.cs_str import set_attr_on_type
 from contrast.utils import Namespace
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
