@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
