@@ -9,7 +9,7 @@ from contrast.api.dtm_pb2 import PathTraversalSemanticAnalysisDetails
 from contrast.utils.decorators import cached_property
 from contrast.utils.stack_trace_utils import StackTraceUtils
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -32,10 +32,10 @@ class PathTraversalSinkFeatures(object):
         "/windows/repair/",
     ]
 
-    def check_sink_features(self, context, attack_vector, attack):
+    def check_sink_features(self, attack_vector, attack):
         new_sample = self.check_custom_code_accessing_system_files(
-            context, attack_vector
-        ) or self.check_file_security_bypass(context, attack_vector)
+            attack_vector
+        ) or self.check_file_security_bypass(attack_vector)
 
         if new_sample:
             if attack is None:
@@ -47,7 +47,7 @@ class PathTraversalSinkFeatures(object):
 
         return attack
 
-    def check_custom_code_accessing_system_files(self, context, attack_vector):
+    def check_custom_code_accessing_system_files(self, attack_vector):
         if (
             self.is_custom_code_access_sysfile_enabled
             and self.is_custom_code_accessing_file_system(attack_vector)
@@ -62,7 +62,7 @@ class PathTraversalSinkFeatures(object):
 
         return None
 
-    def check_file_security_bypass(self, context, attack_vector):
+    def check_file_security_bypass(self, attack_vector):
         if (
             self.is_common_file_exploits_enabled
             and self.contains_known_attack_signatures(attack_vector)
