@@ -4,7 +4,7 @@
 from contrast.applies import apply_rule
 from contrast.utils.patch_utils import patch_cls_or_instance
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
