@@ -14,7 +14,7 @@ from contrast.utils.decorators import cached_property, set_context
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.stack_trace_utils import StackTraceUtils
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
