@@ -3,7 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.protect.rule.base_rule import BaseRule
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
