@@ -10,7 +10,7 @@ from contrast.api import dtm_pb2
 from contrast.utils.timer import Timer
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
