@@ -29,7 +29,7 @@ from contrast.utils.singleton import Singleton
 from contrast.utils.service_util import ServiceUtil
 from contrast.utils.timer import Timer
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -376,10 +376,27 @@ class _ServiceState(Singleton):
         agent_startup.server_version = contrast.__version__
 
         agent_startup.environment = settings.config.get("server.environment")
-        agent_startup.tags = settings.config.get("server.tags")
+
+        agent_startup.server_tags = settings.config.get("server.tags")
+        agent_startup.application_tags = settings.config.get("application.tags")
+        agent_startup.library_tags = settings.config.get("inventory.tags")
+        agent_startup.finding_tags = settings.config.get("assess.tags")
 
         agent_startup.version = contrast.__version__
 
+        settings = SettingsState()
+
+        log_info = {
+            "Server Name": agent_startup.server_name,
+            "Server Path": agent_startup.server_path,
+            "Server Type": agent_startup.server_type,
+            "Application Name": settings.app_name,
+            "Application Path": self.app_path,
+            "Application Language": _APPLICATION_LANGUAGE,
+        }
+
+        logger.info("Application context", **log_info)
+
         return agent_startup
 
     def _build_startup_message(self, settings):
@@ -387,7 +404,6 @@ class _ServiceState(Singleton):
         create.group = settings.config.get("application.group", "")
         create.app_version = settings.config.get("application.version", "")
         create.code = settings.config.get("application.code", "")
-        create.tags = settings.application_tags
 
         create.metadata = settings.config.get("application.metadata", "")
 
