@@ -2,7 +2,6 @@
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
-import socket
 
 from contrast.agent.framework import Framework
 from contrast.agent.heartbeat import Heartbeat
@@ -20,15 +19,12 @@ from contrast.utils.loggers.logger import reset_agent_logger
 from contrast.utils.singleton import Singleton
 from contrast.utils.string_utils import truncate
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
 
 class SettingsState(Singleton, SettingsREPMixin):
-    DEFAULT_HOST = "localhost"
-    DEFAULT_PATH = "/"
-
     def init(self, app_name=None):
         """
         Singletons should override init, not __init__.
@@ -55,11 +51,9 @@ class SettingsState(Singleton, SettingsREPMixin):
         # Rules
         self.defend_rules = dict()
 
-        # Initialize values from config file
-        # Initialize config and loggers
+        # Initialize config
         self.config = AgentConfig()
-        self.application_tags = self.config.get("application.tags", "")
-        self.library_tags = self.config.get("inventory.tags", "")
+
         self.disabled_assess_rules = set(
             self.config.get("assess.rules.disabled_rules", [])
         )
@@ -67,12 +61,6 @@ class SettingsState(Singleton, SettingsREPMixin):
         # Initialize application metadata
         self.app_name = self.get_app_name(app_name)
 
-        # Initialize libraries
-        self.libraries = []
-        self.unused_libraries = []
-        self.top_level_modules = {}
-        self.installed_distribution_keys = []
-
         logger.info("Contrast Agent finished loading settings.")
 
     def _is_defend_enabled_in_server_features(self):
@@ -207,7 +195,11 @@ class SettingsState(Singleton, SettingsREPMixin):
             if self.server_features.log_level == "TRACE"
             else self.server_features.log_level
         )
-        reset_agent_logger(self.server_features.log_file, log_level)
+
+        logger_reset = reset_agent_logger(self.server_features.log_file, log_level)
+
+        if logger_reset:
+            self.config.log_config()
 
     def is_inventory_enabled(self):
         """
@@ -270,11 +262,10 @@ class SettingsState(Singleton, SettingsREPMixin):
         """
         Hostname of the server
 
-        Default is localhost
+        Default is socket.gethostname() or localhost
         """
         if self.server_name is None:
-            detected_server = truncate(socket.gethostname(), self.DEFAULT_HOST)
-            self.server_name = self.config.get("server.name", detected_server)
+            self.server_name = self.config.get("server.name")
 
         return self.server_name
 
@@ -285,8 +276,7 @@ class SettingsState(Singleton, SettingsREPMixin):
         Default is root
         """
         if self.server_path is None:
-            detected_path = truncate(os.getcwd(), self.DEFAULT_PATH)
-            self.server_path = self.config.get("server.path", detected_path)
+            self.server_path = self.config.get("server.path") or truncate(os.getcwd())
 
         return self.server_path
 
