@@ -246,8 +246,11 @@ PyObject *destroy_thread_scope(PyObject *self, PyObject *thread_id) {
     log_debug("destroy thread scope");
 
     scope = pthread_getspecific(thread_key);
-    if (scope != NULL)
+    if (scope != NULL) {
         free(scope);
+        pthread_setspecific(thread_key, NULL);
+    }
+
 
     Py_RETURN_NONE;
 }
