@@ -1,9 +1,10 @@
-import os
 from collections import namedtuple
+import os
 
 import contrast.utils.configuration_utils as utils
 
-import logging
+from contrast.utils.loggers import DEFAULT_PROGNAME
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -45,6 +46,14 @@ class AgentConfig(object):
 
         self._config[key] = value
 
+    def log_config(self):
+        """Log configuration values EXCEPT API information containing sensitive data"""
+        config_no_api = {
+            key: self._config[key] for key in self._config if "api" not in key
+        }
+
+        logger.info("Current Configuration", **config_no_api)
+
     def override_configs(self):
         """
         For each class representing different parts of the config (Agent, etc),
@@ -67,17 +76,54 @@ class AgentConfig(object):
 
     def check_for_service_config(self):
         """
-        Don't do anything if service socket is specified, but if it is not
-        and there are no host or port, assign these.
+        Check for and log user-provided config values for connecting to SR.
+        Socket config takes precedence if it is user-provided. Otherwise assign
+        host/port values if either is not provided.
         """
-        if self.get("agent.service.socket"):
+        socket_key = "agent.service.socket"
+        host_key = "agent.service.host"
+        port_key = "agent.service.port"
+
+        # Socket is set
+        if self.get(socket_key):
+            logger.info(
+                "Connecting to the Contrast Service using a UnixSocket socket: %s",
+                self.get(socket_key),
+            )
             return
 
-        if not self.get("agent.service.host"):
-            self.put("agent.service.host", DEFAULT_SERVICE_HOST)
+        # Host and Port are set
+        if self.get(host_key) and self.get(port_key):
+            logger.info(
+                "Connecting to the Contrast Service using a TCP socket: host: %s, port: %s",
+                self.get(host_key),
+                self.get(port_key),
+            )
+            return
 
-        if not self.get("agent.service.port"):
-            self.put("agent.service.port", DEFAULT_SERVICE_PORT)
+        # Something is not set
+
+        if self.get(host_key):
+            self.put(port_key, DEFAULT_SERVICE_PORT)
+            msg = "{} is not set. Falling back to default TCP socket host: {}, port: {}".format(
+                port_key, self.get(host_key), self.get(port_key)
+            )
+        elif self.get(port_key):
+            self.put(host_key, DEFAULT_SERVICE_HOST)
+            msg = "{} is not set. Falling back to default TCP socket host: {}, port: {}".format(
+                host_key, self.get(host_key), self.get(port_key)
+            )
+        else:
+            self.put(host_key, DEFAULT_SERVICE_HOST)
+            self.put(port_key, DEFAULT_SERVICE_PORT)
+            msg = "Neither {} nor the pair of {} and {} are set. Falling back to default TCP socket host: {}, port: {}.".format(
+                socket_key, host_key, port_key, self.get(host_key), self.get(port_key),
+            )
+
+        msg_prefix = "Missing a required connection value to the Contrast Service."
+        warn_msg = "{} {}".format(msg_prefix, msg)
+
+        logger.warning(warn_msg)
 
     def get_session_id(self):
         return self.get("application.session_id", "")
@@ -142,10 +188,15 @@ class Agent(ConfigBuilder):
 
         self.default_options = [
             # Some logger default values are handled by the logger
-            ConfigOption(name="logger.level", default_value="", type_cast=str),
+            ConfigOption(name="logger.level", default_value="", type_cast=str,),
             ConfigOption(name="logger.path", default_value="", type_cast=str),
             ConfigOption(
-                name="logger.progname", default_value="Contrast Agent", type_cast=str
+                name="logger.progname", default_value=DEFAULT_PROGNAME, type_cast=str,
+            ),
+            ConfigOption(
+                name="python.enable_drf_response_analysis",
+                default_value=True,
+                type_cast=utils.str_to_bool,
             ),
             ConfigOption(
                 name="python.enable_rep",
@@ -354,7 +405,9 @@ class Server(ConfigBuilder):
         super(Server, self).__init__()
 
         self.default_options = [
-            ConfigOption(name="name", default_value="", type_cast=str),
+            ConfigOption(
+                name="name", default_value=utils.get_hostname(), type_cast=str
+            ),
             ConfigOption(name="path", default_value="/", type_cast=str),
             ConfigOption(name="type", default_value="", type_cast=str),
             ConfigOption(name="version", default_value="", type_cast=str),
