@@ -19,11 +19,12 @@ introduce a different version of a particular package.
 
 Packages included:
     - backports.functools_lru_cache-1.5
-    - isort-5.0.0 (dev)
+    - isort-5.6.4 (only the stdlibs subpackage)
     - ruamel.yaml-0.16.10
     - WebOb-1.8.6
     - six-1.14.0
     - wrapt-1.12.1
     - pathlib2-2.3.5 (Python 2.7 only)
     - scandir-1.10.0 (required for pathlib2)
+    - structlog-20.1.0
 """
