@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -16,7 +16,9 @@ from . import (
     lxml_patch,
     pycryptodome_patch,
     pyramid_patch,
+    library_reader_import_patches,
 )
+
 from .databases import (
     mysql_connector_patch,
     pymysql_patch,
@@ -26,10 +28,11 @@ from .databases import (
     sqlite3_patch,
 )
 
+from .frameworks import django_patches, drf_patches
+
 
 COMMON_PATCH_MODULES = (
     cs_logging,
-    threading_patch,
     # pycrypto_patch,
     pycryptodome_patch,
     # pycryptodomex_patch,
@@ -43,6 +46,9 @@ COMMON_PATCH_MODULES = (
 )
 
 
+LIBRARY_READER_PATCHES = (library_reader_import_patches,)
+
+
 ASSESS_PATCH_MODULES = (
     cs_cstringio,
     cs_io,
@@ -50,6 +56,9 @@ ASSESS_PATCH_MODULES = (
     exec_and_eval,
     lxml_patch,
     pyramid_patch,
+    django_patches,
+    drf_patches,
+    threading_patch,
 )
 
 
@@ -62,6 +71,11 @@ def register_module_patches(module, patch_group):
         logger.exception("failed to register patches for %s", module.__name__)
 
 
+def register_library_patches():
+    for module in LIBRARY_READER_PATCHES:
+        register_module_patches(module, "library analysis")
+
+
 def register_common_patches():
     for module in COMMON_PATCH_MODULES:
         register_module_patches(module, "common")
