@@ -9,7 +9,7 @@ from contrast.agent.assess.policy import propagation_policy
 from contrast.utils.assess.stream_utils import BaseStreamProxy, stream_patch_body
 from contrast.utils.patch_utils import patch_cls_or_instance
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
