@@ -9,7 +9,7 @@ from contrast.agent.policy import patch_manager
 from contrast.utils.assess.stream_utils import stream_patch_body
 from contrast.assess_extensions import cs_str
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
