@@ -4,6 +4,8 @@
 """
 Patch for logging module to implement deadzone for logging
 """
+import sys
+from contrast.agent.policy import patch_manager
 from contrast.extern.wrapt import register_post_import_hook
 
 from contrast.agent import scope
@@ -35,3 +37,11 @@ def patch_logging(logging_module):
 
 def register_patches():
     register_post_import_hook(patch_logging, "logging")
+
+
+def reverse_patches():
+    logging_module = sys.modules.get("logging")
+    if not logging_module:
+        return
+
+    patch_manager.reverse_patches_by_owner(logging_module.StreamHandler)
