@@ -8,7 +8,7 @@ Other methods of the `re` module such as `split` and `escape` can be patched dir
 so they are implemented in policy.
 """
 import functools
-import logging
+from contrast.extern import structlog as logging
 import sys
 
 from contrast.extern.wrapt import register_post_import_hook
