@@ -9,7 +9,7 @@ from contrast.patches.databases import dbapi2
 from contrast.utils import inventory_utils
 from contrast.utils.patch_utils import patch_cls_or_instance
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
