@@ -10,14 +10,22 @@ import pytest
 from app import settings
 from app.urls import urlpatterns
 
-from django import __version__ as django_version
+import django
 from django.utils.html import escape
-from django.test import Client
 from contrast.agent.protect.rule.deserialization_rule import Deserialization
 from contrast.api.dtm_pb2 import AttackResult, ObservedRoute
 from contrast.api.settings_pb2 import ProtectionRule
-from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.test import mocks
+
+from contrast.test.library_analysis import (
+    assert_files_loaded,
+    import_sample_package_onefile,
+    TEST_MODULES_RELATIVE_IMPORT_DIST,
+    TEST_MODULES_NAMESPACE_DIST,
+    TEST_MODULE_ONEFILE,
+    TEST_MODULES_MULTIPLE_TLDS_DIST,
+)
+
 from contrast.test.contract.findings import (
     assert_event_sources,
     param_is_tracked,
@@ -26,11 +34,12 @@ from contrast.test.contract.findings import (
     validate_source_finding,
     validate_header_sources,
     validate_cookies_sources,
+    validate_nondataflow_finding,
+    validate_ssrf_finding,
 )
 from contrast.test.apptest_utils import (
     assert_route_appended,
     assert_routes_count,
-    assert_ssrf_finding,
     current_routes_by_url,
     validate_observed_route,
     assert_subprocess_popen_finding_events,
@@ -40,11 +49,13 @@ from contrast.test.helper import (
     mock_build_update_messages,
     mock_send_messages,
     python2_only,
-    skip_no_mongo_db,
 )
+from contrast.test.mongo import skip_no_mongo_db
+
+from vulnpy.trigger import sqli
 
 URLPATTERNS_COPY = copy.copy(urlpatterns)
-BASE_DIR = os.path.abspath(os.curdir)
+DATA_DIR = os.path.join(settings.BASE_DIR, os.pardir, "data")
 
 
 SOURCE_OPTIONS = (
@@ -56,99 +67,143 @@ SOURCE_OPTIONS = (
     "referer_header",
 )
 
-# full_path_info is only in newer versions of django. We do not test it for POST
-# requests since in this case the path does not contain a query, and so the entire path
-# is actually sanitized.
-GET_SOURCES = SOURCE_OPTIONS + (("full_path", "full_path_info",) if six.PY3 else ())
-POST_SOURCES = ("files", "body",) + SOURCE_OPTIONS + (("full_path",) if six.PY3 else ())
+# full_path_info is only in newer versions of django.
+# We do not test full_path* for POST requests since in this case the path does not contain
+# a query, and so the entire path is actually sanitized.
+GET_SOURCES = (
+    SOURCE_OPTIONS
+    + ("full_path",)
+    + (("full_path_info",) if django.VERSION >= (2, 1) else ())
+)
+POST_SOURCES = ("files", "body",) + SOURCE_OPTIONS
+
+
+class DjangoTestLibraryAnalysisBuiltinImport(object):
+    def test_relative_import_hook(self):
+        response = self.client.get(
+            "/import_package_with_relative_imports/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(
+            self.request_context.activity, TEST_MODULES_RELATIVE_IMPORT_DIST
+        )
+
+    def test_namespace_sample_package_import_hook(self):
+        response = self.client.get(
+            "/import_namespace_package/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(self.request_context.activity, TEST_MODULES_NAMESPACE_DIST)
+
+    def test_module_import_onefile(self):
+        response = self.client.get(
+            "/import_package_onefile/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(self.request_context.activity, TEST_MODULE_ONEFILE)
+
+    def test_sample_module_multiple_tlds(self):
+        response = self.client.get(
+            "/import_sample_dist_multiple_tlds/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(
+            self.request_context.activity, TEST_MODULES_MULTIPLE_TLDS_DIST
+        )
+
+    def test_module_already_imported(self):
+        import_sample_package_onefile()
+
+        response = self.client.get("/import_package_onefile/")
+
+        assert response.status_code == 200
+
+        assert len(self.request_context.activity.library_usages) == 0
 
 
-@skip_no_mongo_db
 class DjangoProtectNoSqliTestMixin(object):
     """
     Screener does not currently test nosqli protect so we test it more thoroughly.
     """
 
-    def make_nosqli_request(self, client, method, param_val, with_kwarg):
-        if django_version < "1.11":
-            # SecurityException is not raised in legacy django middleware
-            client.post(
-                "/nosqli/",
-                {"user_input": param_val, "with_kwarg": with_kwarg},
-                method_to_test=method,
-            )
-        else:
-            with pytest.raises(SecurityException):
-                client.post(
-                    "/nosqli/",
-                    {"user_input": param_val, "with_kwarg": with_kwarg},
-                    method_to_test=method,
-                )
+    def make_nosqli_request(self, method, param_val, with_kwarg):
+        self.client.post(
+            "/nosqli/",
+            {
+                "user_input": param_val,
+                "method_to_test": method,
+                "with_kwarg": with_kwarg,
+            },
+            status=403,
+        )
 
+    @skip_no_mongo_db
     @mocks.nosqli_input_analysis_mock
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_nosqli_find_blocked(self, mocked_input_analysis, with_kwarg):
-        c = Client()
-
         param_val = "Record One"
 
-        self.make_nosqli_request(c, "find", param_val, with_kwarg)
+        self.make_nosqli_request("find", param_val, with_kwarg)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "nosql-injection"
         assert self.request_context.activity.query_count == 1
 
+    @skip_no_mongo_db
     @mocks.nosqli_input_analysis_mock
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_nosqli_insert_one_blocked(self, mocked_input_analysis, with_kwarg):
-        c = Client()
-
         param_val = '{"title": "Record One"}'
 
-        self.make_nosqli_request(c, "insert_one", param_val, with_kwarg)
+        self.make_nosqli_request("insert_one", param_val, with_kwarg)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "nosql-injection"
         assert self.request_context.activity.query_count == 1
 
+    @skip_no_mongo_db
     @mocks.nosqli_input_analysis_mock
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_nosqli_insert_many_blocked(self, mocked_input_analysis, with_kwarg):
-        c = Client()
-
         param_val = "Record One"
 
-        self.make_nosqli_request(c, "insert_many", param_val, with_kwarg)
+        self.make_nosqli_request("insert_many", param_val, with_kwarg)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "nosql-injection"
         assert self.request_context.activity.query_count == 1
 
+    @skip_no_mongo_db
     @mocks.nosqli_input_analysis_mock
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_nosqli_update_blocked(self, mocked_input_analysis, with_kwarg):
-        c = Client()
-
         param_val = "Record One"
 
-        self.make_nosqli_request(c, "update", param_val, with_kwarg)
+        self.make_nosqli_request("update", param_val, with_kwarg)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "nosql-injection"
         assert self.request_context.activity.query_count == 2
 
+    @skip_no_mongo_db
     @mocks.nosqli_input_analysis_mock
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_nosqli_delete_blocked(self, mocked_input_analysis, with_kwarg):
-        c = Client()
-
         param_val = "Record One"
 
-        self.make_nosqli_request(c, "delete", param_val, with_kwarg)
+        self.make_nosqli_request("delete", param_val, with_kwarg)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
@@ -182,19 +237,11 @@ class DjangoProtectTestMixinBlock(DjangoProtectNoSqliTestMixin):
 
     @pytest.mark.parametrize("path", ["os-system", "subprocess-popen"])
     def test_cmdi(self, path):
-        c = Client()
-        if django_version < "1.11":
-            # SecurityException is not raised by legacy django middleware client
-            c.get(
-                "/vulnpy/cmdi/{}".format(path),
-                {"user_input": "; echo /etc/passwd | nc"},
-            )
-        else:
-            with pytest.raises(SecurityException):
-                c.get(
-                    "/vulnpy/cmdi/{}".format(path),
-                    {"user_input": "; echo /etc/passwd | nc"},
-                )
+        self.client.get(
+            "/vulnpy/cmdi/{}".format(path),
+            {"user_input": "; echo /etc/passwd | nc"},
+            status=403,
+        )
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "cmd-injection"
@@ -205,16 +252,9 @@ class DjangoProtectTestMixinBlock(DjangoProtectNoSqliTestMixin):
         param_val = "csubprocess\ncheck_output\n(S'ls'\ntR."
 
         params = dict(user_input=param_val)
+        method = getattr(self.client, method_name)
 
-        c = Client()
-        method = getattr(c, method_name)
-
-        if django_version < "1.11":
-            # SecurityException is not raised by legacy django middleware client
-            method("/vulnpy/deserialization/{}".format(trigger), params)
-        else:
-            with pytest.raises(SecurityException):
-                method("/vulnpy/deserialization/{}".format(trigger), params)
+        method("/vulnpy/deserialization/{}".format(trigger), params, status=403)
 
         assert len(self.request_context.activity.results) == 1
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
@@ -275,10 +315,9 @@ class DjangoAssessTestMixin(object):
 
     def test_byte_file_contents_are_tracked(self):
         filename = "logo.png"
-        file_path = os.path.join(BASE_DIR, "..", "data", filename)
+        file_path = os.path.join(DATA_DIR, filename)
 
-        with open(file_path, "rb") as fp:
-            self.client.post("/file-contents/", {"upload": fp})
+        self.client.post("/file-contents/", upload_files=[("upload", file_path)])
 
         assert param_is_tracked(filename)
 
@@ -292,12 +331,10 @@ class DjangoAssessTestMixin(object):
         assert param_is_tracked(file_end)
 
     @mocks.build_finding
-    def test_cmdi_base64_encoded(self, mocked):
+    def test_uce_base64(self, mocked):
         # this string is "__import__('os').system('echo hacked')" b64 encoded
         encoded_input = "X19pbXBvcnRfXygnb3MnKS5zeXN0ZW0oJ2VjaG8gaGFja2VkJyk="
-        response = self.client.get(
-            "/cmdi-base64-encoded/", {"user_input": encoded_input}
-        )
+        response = self.client.get("/uce-base64/", {"user_input": encoded_input})
 
         assert response.status_code == 200
         assert len(self.request_context.activity.findings) == 1
@@ -317,8 +354,11 @@ class DjangoAssessTestMixin(object):
         param_val = "book title"
         response = self.client.post(
             "/nosqli/",
-            {"user_input": param_val, "with_kwarg": with_kwarg},
-            method_to_test="find",
+            {
+                "user_input": param_val,
+                "method_to_test": "find",
+                "with_kwarg": with_kwarg,
+            },
         )
 
         validate_finding(
@@ -348,8 +388,11 @@ class DjangoAssessTestMixin(object):
 
         response = self.client.post(
             "/nosqli/",
-            {"user_input": param_val, "with_kwarg": with_kwarg},
-            method_to_test="insert_one",
+            {
+                "user_input": param_val,
+                "method_to_test": "insert_one",
+                "with_kwarg": with_kwarg,
+            },
         )
 
         validate_any_finding(
@@ -374,8 +417,11 @@ class DjangoAssessTestMixin(object):
 
         response = self.client.post(
             "/nosqli/",
-            {"user_input": param_val, "with_kwarg": with_kwarg},
-            method_to_test="insert_many",
+            {
+                "user_input": param_val,
+                "method_to_test": "insert_many",
+                "with_kwarg": with_kwarg,
+            },
         )
 
         validate_finding(
@@ -385,7 +431,7 @@ class DjangoAssessTestMixin(object):
             param_val,
             mocked,
             "nosql-injection",
-            1,
+            2,  # extra weak-randomness finding
         )
 
     @skip_no_mongo_db
@@ -394,7 +440,7 @@ class DjangoAssessTestMixin(object):
         param_val = "New Title"
 
         response = self.client.post(
-            "/nosqli/", {"user_input": param_val}, method_to_test="update"
+            "/nosqli/", {"user_input": param_val, "method_to_test": "update"},
         )
 
         validate_finding(
@@ -415,7 +461,7 @@ class DjangoAssessTestMixin(object):
         )
 
         response = self.client.post(
-            "/nosqli/", {"user_input": param_val}, method_to_test="delete"
+            "/nosqli/", {"user_input": param_val, "method_to_test": "delete"},
         )
 
         validate_finding(
@@ -447,7 +493,11 @@ class DjangoAssessTestMixin(object):
             "cmd-injection",
             1,
         )
-        if path == "subprocess-popen" and method == "get":
+        if (
+            path == "subprocess-popen"
+            and method == "get"
+            and not os.environ.get("USE_DJANGO_WSGI")  # TODO: PYT-1102
+        ):
             assert_subprocess_popen_finding_events(
                 self.request_context.activity.findings
             )
@@ -490,7 +540,7 @@ class DjangoAssessTestMixin(object):
     def test_xss_escaped_no_vuln(self, mocked):
         param_val = "<script>alert(1)</script>"
         response = self.client.get(
-            "/xss/", {"user_input": param_val}, django_escape=True
+            "/xss/", {"user_input": param_val, "django_escape": "True"},
         )
 
         assert response is not None
@@ -529,7 +579,7 @@ class DjangoAssessTestMixin(object):
             self.request_context.activity.findings,
             response,
             param_val,
-            response.content,
+            response.body,
             mocked,
             "reflected-xss",
             1,
@@ -537,7 +587,7 @@ class DjangoAssessTestMixin(object):
 
     @mocks.build_finding
     def test_xss_mako(self, mocked):
-        if django_version.startswith("3"):
+        if django.VERSION[:1] == (3,):
             pytest.xfail("djangomako is broken in Django 3")
 
         param_val = "im an attack!"
@@ -547,13 +597,13 @@ class DjangoAssessTestMixin(object):
             self.request_context.activity.findings,
             response,
             param_val,
-            response.content,
+            response.body,
             mocked,
             "reflected-xss",
             1,
         )
 
-    @pytest.mark.parametrize("route", ["/raw-xss/", "/raw-xss-streaming/"])
+    @pytest.mark.parametrize("route", ["/vulnpy/xss/raw", "/raw-xss-streaming/"])
     @mocks.build_finding
     def test_xss_raw(self, mocked, route):
         param_val = "im an attack!"
@@ -563,11 +613,10 @@ class DjangoAssessTestMixin(object):
 
         if "streaming" in route:
             # Make sure that our middleware doesn't consume streaming content
-            content = list(response.streaming_content)
-            assert content
-            assert content[0] == b"<p>Looks like xss: im an attack!</p>"
+            content = response.body
+            assert content == b"<p>Looks like xss: im an attack!</p>"
         else:
-            assert response.content == b"<p>Looks like xss: im an attack!</p>"
+            assert "<p>XSS: {}</p>".format(param_val) in str(response.body)
 
         assert mocked.called
         assert mocked.call_args[0][1].name == "reflected-xss"
@@ -586,10 +635,9 @@ class DjangoAssessTestMixin(object):
     @mocks.build_finding
     def test_cmdi_from_filename_and_contents(self, mocked):
         filename = "testfile.txt"
-        file_path = os.path.join(BASE_DIR, "..", "data", filename)
+        file_path = os.path.join(DATA_DIR, filename)
 
-        with open(file_path) as fp:
-            response = self.client.post("/cmdi-file/", {"upload": fp})
+        response = self.client.post("/cmdi-file/", upload_files=[("upload", file_path)])
 
         data_path = os.path.join(settings.MEDIA_ROOT, "data")
         result = "cp {0}/testfile.txt {0}/testfile.txt.bak".format(data_path)
@@ -617,64 +665,49 @@ class DjangoAssessTestMixin(object):
         assert mocked.call_args[0][1].name == "untrusted-deserialization"
         assert len(self.request_context.activity.findings) == 1
 
-    def _build_ssrf_request(self, module, with_kwarg, use_https=None):
-        data = {
-            "url": "http://example.com/?q=foobar",
-            "path": "/index.html",
-            "hostname": "example.com",
-            "module": module,
-            "method": "GET",
-            "with_kwarg": with_kwarg,
-        }
-        if use_https is not None:
-            data["use_https"] = use_https
-        return data
-
     @pytest.mark.parametrize(
-        "module",
-        (
-            ["urllib", "urllib2_str", "urllib2_obj"]
-            if six.PY2
-            else ["urllib.request_str", "urllib.request_obj"]
-        ),
+        "trigger", ["legacy-urlopen", "urlopen-str", "urlopen-obj"]
     )
-    @pytest.mark.parametrize("with_kwarg", [False, True])
+    @pytest.mark.parametrize("safe", [False, True])
     @mocks.build_finding
-    def test_ssrf_dynamic_urllib(self, mocked, with_kwarg, module):
-        response = self.client.post(
-            "/ssrf-dynamic/", self._build_ssrf_request(module, with_kwarg)
+    def test_ssrf_urllib(self, mocked, trigger, safe):
+        user_input = "not.a.url" if safe else "http://attacker.com/?q=foobar"
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": user_input},
         )
         assert response.status_code == 200
-        assert_ssrf_finding(module, self.request_context, mocked)
+        if not safe:
+            validate_ssrf_finding(trigger, self.request_context, mocked)
+        else:
+            assert not mocked.called
+            assert len(self.request_context.activity.findings) == 0
 
+    @pytest.mark.parametrize("trigger_class", ["httpconnection", "httpsconnection"])
     @pytest.mark.parametrize(
-        "module",
-        ["HTTPConnection.__init__"]
-        + ["HTTPConnection.request-method", "HTTPConnection.putrequest-method"],
+        "trigger_method", ["request-method", "putrequest-method", "init"]
     )
-    @pytest.mark.parametrize("use_https", [False, True])
-    @pytest.mark.parametrize("with_kwarg", [False, True])
     @mocks.build_finding
-    def test_ssrf_dynamic_httpclient(self, mocked, with_kwarg, use_https, module):
-        response = self.client.post(
-            "/ssrf-dynamic/", self._build_ssrf_request(module, with_kwarg, use_https)
+    def test_ssrf_httplib(self, mocked, trigger_method, trigger_class):
+        trigger = "-".join([trigger_class, trigger_method])
+        user_input = "www.attacker.com" if trigger_method == "init" else "DELETE"
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": user_input},
         )
         assert response.status_code == 200
-        assert_ssrf_finding(module, self.request_context, mocked)
+        validate_ssrf_finding(trigger, self.request_context, mocked)
 
-    @pytest.mark.parametrize(
-        "module", ["HTTPConnection.request", "HTTPConnection.putrequest"]
-    )
-    @pytest.mark.parametrize("use_https", [False, True])
-    @pytest.mark.parametrize("with_kwarg", [False, True])
+    @pytest.mark.parametrize("trigger_class", ["httpconnection", "httpsconnection"])
+    @pytest.mark.parametrize("trigger_method", ["request", "putrequest"])
     @mocks.build_finding
-    def test_ssrf_dynamic_safe(self, mocked, with_kwarg, use_https, module):
+    def test_ssrf_httplib_safe(self, mocked, trigger_method, trigger_class):
         """
-        These triggers aren't vulnerable to SSRF, because they only accept
-        path/querystring as the URL argument, which can't trigger SSRF.
+        HTTP*Connection.*request isn't vulnerable to SSRF via the "url" argument.
+        This is because it only takes a path / querystring, which isn't vulnerable
+        to ssrf.
         """
-        response = self.client.post(
-            "/ssrf-dynamic/", self._build_ssrf_request(module, with_kwarg, use_https)
+        trigger = "-".join([trigger_class, trigger_method, "url"])
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": "/some/path"},
         )
         assert response.status_code == 200
         assert not mocked.called
@@ -712,7 +745,7 @@ class DjangoAssessTestMixin(object):
         # suite runs, it will not. The findings are both present, but the first one
         # has way more events than the second one for some reason. It seems like
         # something in the test environment is polluting this test state somehow.
-        if django_version.startswith("1.10"):
+        if django.VERSION[:2] == (1, 10):
             pytest.xfail("Known weirdness with events on django-1.10.8 apptest")
 
         self.client.get("/vulnpy/cmdi/os-system", {"user_input": "first attack"})
@@ -783,13 +816,17 @@ class DjangoAssessTestMixin(object):
         )
 
     @python2_only
+    @pytest.mark.xfail(
+        os.environ.get("USE_DJANGO_WSGI") is not None, reason="TODO: PYT-1096"
+    )
     def test_untrusted_execfile(self):
         user_input = "fake_filename.py"
-        self.client.get("/untrusted-execfile/", dict(user_input=user_input))
+        self.client.get("/vulnpy/pt/execfile/", dict(user_input=user_input))
 
-        assert len(self.request_context.activity.findings) == 2
+        assert len(self.request_context.activity.findings) == 1
         assert self.request_context.activity.findings[0].rule_id == u"path-traversal"
 
+    @pytest.mark.xfail(django.VERSION[:2] == (1, 9), reason="TODO: PYT-1050")
     @pytest.mark.parametrize(
         "test_type",
         [
@@ -810,7 +847,7 @@ class DjangoAssessTestMixin(object):
         findings = self.request_context.activity.findings
 
         validate_finding(
-            findings, response, param_val, response.content, mocked, "reflected-xss", 1
+            findings, response, param_val, response.body, mocked, "reflected-xss", 1
         )
 
         assert_event_sources(findings, "database", {"database": "TAINTED_DATABASE"})
@@ -824,6 +861,114 @@ class DjangoAssessTestMixin(object):
         assert len(findings) == 1
         assert findings[0].rule_id == "xpath-injection"
 
+    @pytest.mark.parametrize("trigger", ["io-open", "open"])
+    @mocks.build_finding
+    def test_path_traversal(self, mocked, trigger):
+        param_val = "doesnt matter"
+        response = self.client.get(
+            "/vulnpy/pt/{}".format(trigger), {"user_input": param_val}
+        )
+
+        validate_finding(
+            self.request_context.activity.findings,
+            response,
+            param_val,
+            param_val,
+            mocked,
+            "path-traversal",
+            1,
+        )
+
+    @pytest.mark.django_db(transaction=False)
+    @pytest.mark.parametrize("method", ["get", "post"])
+    @mocks.build_finding
+    def test_sqli_via_django_orm(self, mocked, method):
+        param_val = "doesnt matter"
+        get_or_post = getattr(self.client, method)
+        response = get_or_post("/sqli/", {"user_input": param_val})
+
+        query = "SELECT * FROM app_message WHERE id = 'doesnt matter'"
+
+        validate_finding(
+            self.request_context.activity.findings,
+            response,
+            param_val,
+            query,
+            mocked,
+            "sql-injection",
+            1,
+        )
+
+    @pytest.mark.parametrize(
+        "trigger,query_fmt",
+        [
+            ("sqlite3-execute", sqli.EXECUTE_QUERY_FMT),
+            ("sqlite3-executemany", sqli.EXECUTEMANY_QUERY_FMT),
+            ("sqlite3-executescript", sqli.EXECUTESCRIPT_QUERY_FMT,),
+        ],
+    )
+    @mocks.build_finding
+    def test_sqli(self, mocked, trigger, query_fmt):
+        user_input = "any value works"
+        response = self.client.get(
+            "/vulnpy/sqli/{}".format(trigger), {"user_input": user_input}
+        )
+
+        query = query_fmt.format(user_input)
+
+        validate_finding(
+            self.request_context.activity.findings,
+            response,
+            user_input,
+            query,
+            mocked,
+            "sql-injection",
+            1,
+        )
+
+
+class DjangoAssessTestNondataflowMixin(object):
+    @pytest.mark.parametrize("trigger", ["random", "randint", "randrange", "uniform"])
+    @mocks.build_finding
+    def test_crypto_weak_randomness(self, mocked, trigger):
+        response = self.client.get(
+            "/vulnpy/rand/{}".format(trigger), {"user_input": "abc123"}
+        )
+        validate_nondataflow_finding(
+            self.request_context.activity.findings,
+            response,
+            mocked,
+            "crypto-weak-randomness",
+            1,
+        )
+
+    @pytest.mark.parametrize("trigger", ["hashlib-md5", "hashlib-sha1", "hashlib-new"])
+    @mocks.build_finding
+    def test_crypto_bad_mac(self, mocked, trigger):
+        response = self.client.get(
+            "/vulnpy/hash/{}".format(trigger), {"user_input": "def456"}
+        )
+        validate_nondataflow_finding(
+            self.request_context.activity.findings,
+            response,
+            mocked,
+            "crypto-bad-mac",
+            1,
+        )
+
+    @mocks.build_finding
+    def test_crypto_bad_ciphers(self, mocked):
+        response = self.client.get("/crypto-bad-ciphers/")
+
+        validate_nondataflow_finding(
+            self.request_context.activity.findings,
+            response,
+            mocked,
+            "crypto-bad-ciphers",
+            8,
+            1,
+        )
+
 
 class DjangoRouteCoverageTestMixin(object):
     @mock_build_update_messages
@@ -848,7 +993,7 @@ class DjangoRouteCoverageTestMixin(object):
         self.client.get("/dynamic_url_view/", {"user_input": new_view})
 
         routes = build_update_message.call_args[0][0]
-        dynamic_routes = current_routes_by_url(routes, new_view + "/")
+        dynamic_routes = current_routes_by_url(routes, new_view)
         assert_routes_count(dynamic_routes, 2)
 
     @mock_send_messages
@@ -860,14 +1005,13 @@ class DjangoRouteCoverageTestMixin(object):
         Tests that a dynamically-created route is found because it is visited. The
         endpoint that created this route was not the first request to the app.
         """
-        new_view = "new_dynamic"
+        new_view = "other_dynamic"
         original_url_names = [x.name for x in URLPATTERNS_COPY[1:]]
         assert new_view not in original_url_names
-
         self.client.get("/")
 
         routes = build_update_message.call_args[0][0]
-        current_routes = current_routes_by_url(routes, "/" + new_view)
+        current_routes = current_routes_by_url(routes, new_view)
         # new_dynamic has not been created so it is not found
         assert_routes_count(current_routes, 0)
 
@@ -877,14 +1021,18 @@ class DjangoRouteCoverageTestMixin(object):
 
         assert len(send_messages.call_args[0][0]) == 3
 
-        self.client.get("/" + new_view + "/")
+        new_path = "/" + new_view + "/"
+        self.client.get(new_path)
         call_args = send_messages.call_args[0][0]
         assert len(call_args) == 3
 
         observed_route = call_args[2]
         assert isinstance(observed_route, ObservedRoute)
-        assert observed_route.url == new_view + "/"
-        assert observed_route.signature == "app.view_definitions.new_dynamic(request,)"
+        assert observed_route.url == new_path
+        assert (
+            observed_route.signature
+            == "contrast.test.apptest.django_views.other_dynamic(request,)"
+        )
 
     def test_route_appended_to_xss_vuln(self):
         param_val = "im an attack!"
@@ -892,13 +1040,13 @@ class DjangoRouteCoverageTestMixin(object):
 
         assert response
         assert len(self.request_context.activity.findings) > 0
-        assert_route_appended(self.request_context.activity.findings, "xss/", "GET")
+        assert_route_appended(self.request_context.activity.findings, "xss", "GET")
 
     @pytest.mark.django_db(transaction=False)
     def test_observed_route_appended(self):
         param_val = "im an attack!"
         param_name = "user_input"
-        url = "/sqli/"
+        url = "/sqli"
         response = self.client.get(url, {param_name: param_val})
 
         assert response
@@ -907,24 +1055,10 @@ class DjangoRouteCoverageTestMixin(object):
             self.request_context, "GET", url[1:], param_name, "PARAMETER"
         )
 
-    # We should get a finding whether or not the input is valid
-    @pytest.mark.parametrize("param_val", ["0 + 1 + 2", "garbage"])
-    @mocks.build_finding
-    def test_unsafe_code_execution_eval(self, mocked, param_val):
-        response = self.client.get(
-            "/unsafe-code-exec/", {"user_input": param_val, "with_eval": True}
-        )
-
-        validate_finding(
-            self.request_context.activity.findings,
-            response,
-            param_val,
-            param_val,
-            mocked,
-            "unsafe-code-execution",
-            1 if six.PY3 else 2,
-        )
-
+    @pytest.mark.xfail(
+        os.environ.get("USE_DJANGO_WSGI") is not None and six.PY2,
+        reason="TODO: PYT-1096",
+    )
     @pytest.mark.parametrize("setdefault", [False, True])
     def test_trust_boundary_violation(self, setdefault):
         self.client.get(
@@ -933,20 +1067,26 @@ class DjangoRouteCoverageTestMixin(object):
             )
         )
 
-        assert len(self.request_context.activity.findings) == 1
+        # the wsgi middleware is early enough to see a crypto-bad-mac in an earlier middleware
+        # the django middleware is last in the middleware stack, so it misses this vulnerability
+        assert (
+            len(self.request_context.activity.findings) == 2
+            if os.environ.get("USE_DJANGO_WSGI")  # TODO: PYT-1102
+            else 1
+        )
         assert (
             self.request_context.activity.findings[0].rule_id
             == "trust-boundary-violation"
         )
 
 
-class DjangoAssessTestDynamicSources(object):
+class DjangoAssessTestDynamicSourcesMixin(object):
 
     ATTACK_VALUE = "im an attack!"
     DYNAMIC_SOURCE_RULE_ID = "cmd-injection"
 
     def set_dangerous_cookie(self):
-        self.client.cookies["user_input"] = self.ATTACK_VALUE
+        self.client.set_cookie("user_input", self.ATTACK_VALUE)
 
     @mocks.build_finding
     def test_xss_from_cookie(self, mocked):
@@ -962,8 +1102,8 @@ class DjangoAssessTestDynamicSources(object):
         response = self.client.get(
             "/dynamic-sources/",
             {"user_input": self.ATTACK_VALUE, "source": source},
-            HTTP_REFERER="www.python.org",
-            **{source: self.ATTACK_VALUE}
+            headers={"Referer": "www.python.org"},
+            # **{source: self.ATTACK_VALUE}
         )
 
         validate_source_finding(
@@ -980,20 +1120,20 @@ class DjangoAssessTestDynamicSources(object):
     def test_all_post_sources(self, mocked, source):
         self.set_dangerous_cookie()
         if source == "files":
-            file_path = os.path.join(BASE_DIR, "..", "data", "testfile.txt")
-            with open(file_path, "rb") as fp:
-                response = self.client.post(
-                    "/dynamic-sources/",
-                    {"source": source, "user_input": fp},
-                    HTTP_REFERER="www.python.org",
-                )
+            file_path = os.path.join(DATA_DIR, "testfile.txt")
+            response = self.client.post(
+                "/dynamic-sources/",
+                {"source": source},
+                upload_files=[("user_input", file_path)],
+                headers={"Referer": "www.python.org"},
+            )
 
         else:
             response = self.client.post(
                 "/dynamic-sources/",
                 {"user_input": self.ATTACK_VALUE, "source": source},
-                HTTP_REFERER="www.python.org",
-                **{source: self.ATTACK_VALUE}
+                headers={"Referer": "www.python.org"},
+                # **{source: self.ATTACK_VALUE}
             )
 
         validate_source_finding(
@@ -1028,7 +1168,7 @@ class DjangoAssessTestDynamicSources(object):
     @mocks.build_finding
     def test_header_source(self, mocked, use_environ, method_name, route, source_name):
         method = getattr(self.client, method_name)
-        method(route, HTTP_TEST_HEADER="whatever", use_environ=use_environ)
+        method(route, headers={"Test-Header": "whatever"})
 
         validate_header_sources(self.request_context.activity.findings, source_name)
 
