@@ -5,19 +5,19 @@
 Definitions of view functions that can be used in django app tests.
 """
 import base64
+import csv
 import io
 import json
 import os
 import pickle
-
-import lxml.etree
 from xml.etree import ElementTree
 
-import six  # pylint: disable=did-not-import-extern
-from six.moves import http_client as http  # pylint: disable=did-not-import-extern
-import mock
 
-from django import __version__ as django_version
+import lxml.etree
+import six  # pylint: disable=did-not-import-extern
+from Crypto.Cipher import Blowfish
+
+import django
 from django.contrib.auth import logout as DjangoLogout
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
@@ -26,9 +26,23 @@ from django.shortcuts import redirect, render
 from django.views.decorators.http import require_http_methods
 from django.views.decorators.csrf import csrf_exempt
 
-from contrast.test.helper import create_mongo_client
+from contrast.test.mongo import create_mongo_client
+
+from contrast.test.library_analysis import (
+    remove_sys_module_entries,
+    import_with_relative_imports,
+    import_namespace_package,
+    import_sample_package_onefile,
+    import_multiple_tlds,
+)
+
 from vulnpy.trigger import cmdi
 
+try:
+    from django.urls import re_path as compat_url
+except ImportError:
+    from django.conf.urls import url as compat_url
+
 try:
     from app.models import Message
 except ImportError:
@@ -44,17 +58,15 @@ except ImportError:
     JINJA_ENV = None
 
 
-if six.PY2:
-    import urllib
-    import urllib2
-else:
-    import urllib.request
-
 # This ends up resolving to a path relative to the apptest dir so that we don't
 # have to package this data file with the contrast module.
 DATA_DIR = os.path.join("..", "data")
 
 
+def home(request):
+    return render(request, "base.html")
+
+
 def static_image(request):
     filename = request.GET.get("filename", "image.jpg")
     image_path = os.path.join(DATA_DIR, filename)
@@ -94,12 +106,13 @@ def file_contents(request):
     return render(request, "base.html")
 
 
-def django_cmdi_base64_encoded(request):
+def uce_base64(request):
     """
     Adapted from a vulnerable view in lets-be-bad-guys.
     The user_input param must base64 encoded string.
     Example: X19pbXBvcnRfXygnb3MnKS5zeXN0ZW0oJ2VjaG8gaGFja2VkJyk%3D
     this decodes to "__import__('os').system('echo hacked')"
+    Note that in the example, UCE can lead to CMDi!
     """
     user_input = six.ensure_str(request.GET.get("user_input", None))
 
@@ -109,22 +122,15 @@ def django_cmdi_base64_encoded(request):
     eval(decoded_input)
 
     return render(
-        request, "cmdi.html", {"result": "decoded input: {}".format(decoded_input)}
+        request,
+        "unsafe_code_exec.html",
+        {
+            "result": "decoded input: {}".format(decoded_input),
+            "user_input": "user input not displayed to prevent XSS",
+        },
     )
 
 
-def create_url_definition(name, view):
-    if django_version < "2":
-        from django.conf.urls import url
-
-        urlpath = url(r"^{}/$".format(name), view, name=name)
-    else:
-        from django.urls import path
-
-        urlpath = path("{}/".format(name), view, name=name)
-    return urlpath
-
-
 def nosqli(request):
     if request.method == "GET":
         return render(request, "nosqli.html")
@@ -133,7 +139,7 @@ def nosqli(request):
         with_kwarg = request.POST.get("with_kwarg", str(False)) == str(True)
         if user_input:
             try:
-                method = request.environ["method_to_test"]
+                method = request.POST["method_to_test"]
             except KeyError:
                 raise Exception(
                     "Must indicate which pymongo collection method to test."
@@ -187,7 +193,7 @@ def run_pymongo(method, user_input, with_kwarg):
 
 def xss(request):
     user_input = request.GET.get("user_input", "")
-    should_escape = request.environ.get("django_escape", False)
+    should_escape = request.GET.get("django_escape", "False") == "True"
 
     if should_escape:
         from django.utils.html import escape
@@ -196,12 +202,6 @@ def xss(request):
     return render(request, "xss.html", {"user_input": user_input})
 
 
-def raw_xss(request):
-    """Test reflected-xss detection without using a template engine"""
-    user_input = request.GET.get("user_input", "")
-    return HttpResponse("<p>Looks like xss: " + user_input + "</p>")
-
-
 def raw_xss_streaming(request):
     user_input = request.GET.get("user_input", "")
     return StreamingHttpResponse(["<p>Looks like xss: " + user_input + "</p>"])
@@ -286,92 +286,6 @@ def stream_source(request):
     )
 
 
-def ssrf_dynamic(request):
-    """
-    This is a POST endpoint, and the sub-requests are "sent" (mocked) as GET requests.
-    This is to prevent interning. If we use GET for the first request, we end up tracking
-    every instance of the string `'GET'`. This includes literals.
-
-    Before we understood this, we were seeing lots of duplicate SSRF events reported here.
-    One event was due to the URL and the other was due to the request method.
-    """
-    url = request.POST.get("url")
-    path = request.POST.get("path")
-    hostname = request.POST.get("hostname")
-    module = request.POST.get("module")
-    method = request.POST.get("method")
-    use_https = request.POST.get("use_https", str(False)) == str(True)
-    trusted_url = "http://python.org"
-    with_kwarg = request.POST.get("with_kwarg", str(False)) == str(True)
-    result = None
-
-    http_client_class = http.HTTPSConnection if use_https else http.HTTPConnection
-
-    try:
-        # python 2 modules
-        if module == "urllib":
-            result = (
-                urllib.urlopen(url=url) if with_kwarg else urllib.urlopen(url)
-            ).getcode()
-        elif module == "urllib2_str":
-            result = (
-                urllib2.urlopen(url=url) if with_kwarg else urllib2.urlopen(url)
-            ).getcode()
-        elif module == "urllib2_obj":
-            req = urllib2.Request(url)
-            result = (
-                urllib2.urlopen(url=req) if with_kwarg else urllib2.urlopen(req)
-            ).getcode()
-        # python 3 modules
-        elif module == "urllib.request_str":
-            result = (
-                urllib.request.urlopen(url=url)
-                if with_kwarg
-                else urllib.request.urlopen(url)
-            ).getcode()
-        elif module == "urllib.request_obj":
-            req = urllib.request.Request(url)
-            result = (
-                urllib.request.urlopen(url=req)
-                if with_kwarg
-                else urllib.request.urlopen(req)
-            ).getcode()
-        elif module == "HTTPConnection.request":
-            conn = http_client_class(trusted_url, 80)
-            # Don't want to create a real connection
-            conn._create_connection = mock.MagicMock()
-            conn.request("GET", path)
-        elif module == "HTTPConnection.request-method":
-            conn = http_client_class(trusted_url, 80)
-            # Don't want to create a real connection
-            conn._create_connection = mock.MagicMock()
-            conn.request(method, trusted_url)
-        elif module == "HTTPConnection.putrequest":
-            conn = http_client_class(trusted_url, 80)
-            # Don't want to create a real connection
-            conn._create_connection = mock.MagicMock()
-            conn.putrequest(method="GET", url=path) if with_kwarg else conn.putrequest(
-                "GET", path
-            )
-        elif module == "HTTPConnection.putrequest-method":
-            conn = http_client_class(trusted_url, 80)
-            # Don't want to create a real connection
-            conn._create_connection = mock.MagicMock()
-            conn.putrequest(
-                method=method, url=trusted_url
-            ) if with_kwarg else conn.putrequest(method, trusted_url)
-        elif module == "HTTPConnection.__init__":
-            conn = (
-                http_client_class(host=hostname)
-                if with_kwarg
-                else http_client_class(hostname)
-            )
-    except Exception as e:
-        result = str(e)
-
-    return render(request, "ssrf.html", {"user_input": url, "result": result})
-
-
 def unvalidated_redirect(request):
     user_input = request.GET.get("user_input", "/cmdi/")
     permanent = request.GET.get("permanent", False)
@@ -394,18 +308,6 @@ def two_vulns(request):
     return HttpResponse("<p>{}</p>".format(user_input))
 
 
-def untrusted_execfile(request):
-    user_input = request.GET.get("user_input", "attack.py")
-
-    try:
-        execfile(user_input)
-    except Exception:
-        pass
-
-    # This is xss too...
-    return HttpResponse("<p>executed statement: {}</p>".format(user_input))
-
-
 def xpath_injection(request):
     query = request.GET.get("query", "")
     module = request.GET.get("module", "")
@@ -458,7 +360,9 @@ def get_dynamic_source(request, request_dict, source):
         user_input = request.encoding
     elif source == "referer_header":
         user_input = (
-            request.headers["Referer"] if six.PY3 else request.META["HTTP_REFERER"]
+            request.headers["Referer"]
+            if django.VERSION >= (2,)
+            else request.META["HTTP_REFERER"]
         )
     elif source == "http_method":
         user_input = request.method
@@ -495,7 +399,7 @@ def header_source(request):
     else:
         user_input = (
             request.headers["Test-Header"]
-            if six.PY3
+            if django.VERSION >= (2,)
             else request.META["HTTP_TEST_HEADER"]
         )
 
@@ -508,11 +412,15 @@ def header_key_source(request):
     use_environ = request.environ.get("use_environ", False)
 
     if use_environ:
-        keys = request.environ.keys()
+        source_dict = request.environ
     else:
-        keys = request.headers.keys() if six.PY3 else request.META.keys()
+        source_dict = request.headers if django.VERSION >= (2,) else request.META
+
+    # roundabout way of getting the key we want out of the dictionary without changing its id
+    user_input = [
+        k for k in source_dict.keys() if k in ("HTTP_TEST_HEADER", "Test-Header")
+    ][0]
 
-    user_input = list(keys)[0]
     cmdi.do_os_system("echo {}".format(user_input))
 
     return HttpResponse("<p>echoed header key: {}</p>".format(user_input))
@@ -552,37 +460,114 @@ def trust_boundary_violation(request):
     return HttpResponse("<p>Trust boundary violation</p>")
 
 
-def get_apptest_urls():
-    # New url/views should be added to this list
-    url_mappings = [
-        ("static-image", static_image),
-        ("xss-autoescape", django_autoescape),
-        ("xss-autoescape-safe", django_autoescape_safe),
-        ("xss-no-autoescape", django_no_autoescape),
-        ("file-contents", file_contents),
-        ("cmdi-base64-encoded", django_cmdi_base64_encoded),
-        ("cmdi-file", cmdi_file),
-        ("nosqli", nosqli),
-        ("stream-source", stream_source),
-        ("cookie-source", cookie_source),
-        ("header-source", header_source),
-        ("header-key-source", header_key_source),
-        ("xss", xss),
-        ("xss-jinja", xss_jinja),
-        ("xss-mako", xss_mako),
-        ("xss-cookie", xss_cookie),
-        ("raw-xss", raw_xss),
-        ("xss-csv", xss_csv),
-        ("raw-xss-streaming", raw_xss_streaming),
-        ("logout", logout),
-        ("ssrf-dynamic", ssrf_dynamic),
-        ("unvalidated-redirect", unvalidated_redirect),
-        ("two-vulns", two_vulns),
-        ("untrusted-execfile", untrusted_execfile),
-        ("dynamic-sources", dynamic_sources),
-        ("stored-xss", stored_xss),
-        ("xpath-injection", xpath_injection),
-        ("trust-boundary-violation", trust_boundary_violation),
-    ]
+def crypto_bad_ciphers(request):
+    cipher_result = Blowfish.new(b"example_len16key", mode=Blowfish.MODE_EAX)
 
-    return [create_url_definition(name, view) for name, view in url_mappings]
+    return render(request, "crypto_bad_ciphers.html", {"result": str(cipher_result)})
+
+
+class Echo:
+    def write(self, value):
+        return value
+
+
+def streaming(request):
+    # Taken from https://docs.djangoproject.com/en/2.0/howto/outputting-csv/#streaming-large-csv-files
+    if request.method == "GET":
+        attack = request.GET.get("attack", False)
+        if attack:
+            rows = (["Row {}".format(idx), str(idx)] for idx in range(65536))
+            pseudo_buffer = Echo()
+            writer = csv.writer(pseudo_buffer)
+            response = StreamingHttpResponse(
+                (writer.writerow(row) for row in rows), content_type="text/csv"
+            )
+            response[
+                "Content-Disposition"
+            ] = 'attachment; filename="runescapetrivia.csv"'
+            return response
+        return render(request, "streaming.html", {"result": ""})
+    return render(request, "streaming.html", {"result": "Try a GET Request instead."})
+
+
+def new_dynamic(request):
+    return render(request, "base.html")
+
+
+def other_dynamic(request):
+    return render(request, "base.html")
+
+
+def dynamic_url_view(request):
+    from app.urls import urlpatterns
+
+    user_input = request.GET.get("user_input", "new_dynamic")
+
+    func = new_dynamic if user_input == "new_dynamic" else other_dynamic
+    urlpatterns.append(compat_url(r"^{}/?$".format(user_input), func))
+    return render(request, "base.html")
+
+
+def nosqli_seed(request):
+    client = create_mongo_client()
+    db = client.pymongo_test_db
+    posts = db.posts
+    post_1 = {
+        "id": "Python and MongoDB",
+        "content": "PyMongo is fun, you guys",
+        "author": "Scott",
+    }
+    post_2 = {
+        "title": "Virtual Environments",
+        "content": "Use virtual environments, you guys",
+        "author": "Scott",
+    }
+    post_3 = {
+        "title": "Learning Python",
+        "content": "Learn Python, it is easy",
+        "author": "Bill",
+    }
+    posts.insert_many([post_1, post_2, post_3])
+    return render(request, "nosqli.html", {"error": "DB Seeded."})
+
+
+def import_package_with_relative_imports(request):
+    rm_modules = request.GET.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_with_relative_imports()
+
+    return HttpResponse("")
+
+
+def import_sample_namespace_package(request):
+    # Deleting top level namespace modules breaks them in py2.
+    # Namespace name is cached in sys modules, but shows up
+    # as a builtin module in py2.
+    import_namespace_package()
+
+    return HttpResponse("")
+
+
+def import_package_onefile(request):
+    rm_modules = request.GET.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_sample_package_onefile()
+
+    return HttpResponse("")
+
+
+def import_sample_dist_multiple_tlds(request):
+    rm_modules = request.GET.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_multiple_tlds()
+
+    return HttpResponse("")
