@@ -16,8 +16,19 @@ from contrast.test.contract.findings import (
     validate_source_finding,
     validate_header_sources,
     validate_cookies_sources,
+    validate_ssrf_finding,
 )
 
+from vulnpy.trigger import sqli
+
+from contrast.test.library_analysis import (
+    assert_files_loaded,
+    import_sample_package_onefile,
+    TEST_MODULES_RELATIVE_IMPORT_DIST,
+    TEST_MODULES_NAMESPACE_DIST,
+    TEST_MODULE_ONEFILE,
+    TEST_MODULES_MULTIPLE_TLDS_DIST,
+)
 
 SOURCE_OPTIONS_MAP = {
     "args": "QUERYSTRING",
@@ -69,10 +80,11 @@ POST_OPTIONS = tuple(POST_OPTIONS_MAP.keys())
 
 
 def assert_flask_sqli_finding_events(finding, source_class_name):
-    assert len(finding.events) == 16
+    assert len(finding.events) == 17
 
+    event_idx = 0
     check_event(
-        finding.events[0],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(constants.CREATION_TYPE),
         class_name=source_class_name,
@@ -80,8 +92,9 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         source_types=["QUERYSTRING"],
         first_parent=None,
     )
+    event_idx += 1
     check_event(
-        finding.events[1],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.OBJECT_KEY + constants.TO_MARKER + constants.RETURN_KEY
@@ -89,10 +102,11 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="encode",
         source_types=[],
-        first_parent=finding.events[0],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 1
     check_event(
-        finding.events[2],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.OBJECT_KEY + constants.TO_MARKER + constants.RETURN_KEY
@@ -100,10 +114,23 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="split",
         source_types=[],
-        first_parent=finding.events[1],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 1
     check_event(
-        finding.events[3],
+        finding.events[event_idx],
+        event_type=TraceEvent.TYPE_PROPAGATION,
+        action=TraceEvent.Action.Value(
+            constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
+        ),
+        class_name="str",
+        method_name="replace",
+        source_types=[],
+        first_parent=finding.events[event_idx - 1],
+    )
+    event_idx += 1
+    check_event(
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
@@ -111,10 +138,11 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="CAST",
         source_types=[],
-        first_parent=finding.events[2],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 1
     check_event(
-        finding.events[4],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
@@ -122,10 +150,11 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="CAST",
         source_types=[],
-        first_parent=finding.events[3],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 1
     check_event(
-        finding.events[5],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.OBJECT_KEY + constants.TO_MARKER + constants.RETURN_KEY
@@ -133,10 +162,11 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="decode",
         source_types=[],
-        first_parent=finding.events[4],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 4
     check_event(
-        finding.events[9],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
@@ -144,10 +174,11 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="concat",
         source_types=[],
-        first_parent=finding.events[8],
+        first_parent=finding.events[event_idx - 1],
     )
+    event_idx += 1
     check_event(
-        finding.events[10],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
@@ -155,7 +186,7 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         class_name="str",
         method_name="concat",
         source_types=[],
-        first_parent=finding.events[9],
+        first_parent=finding.events[event_idx - 1],
     )
 
     # There are a few f-string propagation events here that previously were
@@ -163,8 +194,9 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
     # identical to the input). They are now showing up because we had to make a
     # fix to join propagation, which affects f-strings as well.
 
+    event_idx += 4
     check_event(
-        finding.events[14],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(
             constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
@@ -175,17 +207,69 @@ def assert_flask_sqli_finding_events(finding, source_class_name):
         # TODO: PYT-922 for some reason this event doesn't have any parent_object_ids
         first_parent=None,
     )
+    event_idx += 1
     check_event(
-        finding.events[15],
+        finding.events[event_idx],
         event_type=TraceEvent.TYPE_PROPAGATION,
         action=TraceEvent.Action.Value(constants.TRIGGER_TYPE),
         class_name="sqlite3.Cursor",
         method_name="execute",
         source_types=[],
-        first_parent=finding.events[14],
+        first_parent=finding.events[event_idx - 1],
     )
 
 
+class FlaskTestLibraryAnalysisBuiltinImport(object):
+    def test_relative_import_hook(self):
+        response = self.client.get(
+            "/import_package_with_relative_imports/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(
+            self.request_context.activity, TEST_MODULES_RELATIVE_IMPORT_DIST
+        )
+
+    def test_namespace_sample_package_import_hook(self):
+        response = self.client.get(
+            "/import_namespace_package/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(self.request_context.activity, TEST_MODULES_NAMESPACE_DIST)
+
+    def test_module_import_onefile(self):
+        response = self.client.get(
+            "/import_package_onefile/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(self.request_context.activity, TEST_MODULE_ONEFILE)
+
+    def test_sample_module_multiple_tlds(self):
+        response = self.client.get(
+            "/import_sample_dist_multiple_tlds/", {"rm_sys_mod_entries": 1}
+        )
+
+        assert response.status_code == 200
+
+        assert_files_loaded(
+            self.request_context.activity, TEST_MODULES_MULTIPLE_TLDS_DIST
+        )
+
+    def test_module_already_imported(self):
+        import_sample_package_onefile()
+
+        response = self.client.get("/import_package_onefile/")
+
+        assert response.status_code == 200
+
+        assert len(self.request_context.activity.library_usages) == 0
+
+
 class FlaskAssessTestMixin(object):
     def validate_source_finding(self, response, mocked, source, options_map=None):
         validate_source_finding(
@@ -208,26 +292,39 @@ class FlaskAssessTestMixin(object):
         ret_arg = call_args[0][2]
         assert "HTML_ENCODED" in get_properties(ret_arg).tags
 
+    @pytest.mark.parametrize("method_name", ["get", "post"])
     @mocks.build_finding
-    def test_xss_raw(self, mocked):
+    def test_xss(self, mocked, method_name):
         user_input = "whatever"
-        response = self.client.post("/raw-xss?user_input=" + user_input)
+        method = getattr(self.client, method_name)
+
+        response = method("/vulnpy/xss/raw", {"user_input": user_input})
 
         assert response.status_code == 200
+        validate_finding(
+            self.request_context.activity.findings,
+            response,
+            user_input,
+            response.body,
+            mocked,
+            "reflected-xss",
+            1,
+        )
 
-        assert len(self.request_context.activity.findings) == 1
         finding = self.request_context.activity.findings[0]
-        assert finding.rule_id == "reflected-xss"
 
         trigger_event = finding.events[-1]
         assert trigger_event.signature.class_name == "flask.app.Flask"
         assert trigger_event.signature.method_name == "wsgi_app"
 
     @pytest.mark.parametrize("user_input", ["something <> dangerous", "something safe"])
+    @pytest.mark.parametrize("sanitizer", ["markupsafe", "html"])
     @mocks.apply_trigger
     @mocks.build_finding
-    def test_jinja_sanitized_xss(self, build_finding, apply_trigger, user_input):
-        response = self.client.post("/sanitized-xss?user_input=" + user_input)
+    def test_sanitized_xss(self, build_finding, apply_trigger, user_input, sanitizer):
+        response = self.client.post(
+            "/{}-sanitized-xss?user_input={}".format(sanitizer, user_input)
+        )
 
         assert response.status_code == 200
 
@@ -238,13 +335,12 @@ class FlaskAssessTestMixin(object):
     @pytest.mark.parametrize("source", SOURCE_OPTIONS)
     @mocks.build_finding
     def test_all_get_sources(self, mocked, source):
-        self.client.set_cookie("localhost", "user_input", "attack_cookie")
+        self.client.set_cookie("user_input", "attack_cookie")
         response = self.client.get(
-            "/dynamic-sources/?user_input={}&source={}".format(
-                self.ATTACK_VALUE, source
-            ),
+            "/dynamic-sources/",
+            {"user_input": self.ATTACK_VALUE, "source": source},
             headers={"Referer": "www.python.org"},
-            data={"attack": self.ATTACK_VALUE},
+            extra_environ={"REMOTE_ADDR": "localhost"},
         )
 
         self.validate_source_finding(response, mocked, source)
@@ -252,18 +348,17 @@ class FlaskAssessTestMixin(object):
     @pytest.mark.parametrize("source", SOURCE_OPTIONS + POST_OPTIONS)
     @mocks.build_finding
     def test_all_post_sources(self, mocked, source):
-        self.client.set_cookie("test", "user_input", "attack_cookie")
-        with open(
-            path.join(self.app.root_path, "..", "..", "data", "testfile.txt"), "rb"
-        ) as f:
-            fileobj = (f, "user_input.txt")
-            response = self.client.post(
-                "/dynamic-sources/?user_input={}&source={}".format(
-                    self.ATTACK_VALUE, source
-                ),
-                headers={"Referer": "www.python.org"},
-                data={"user_input": self.ATTACK_VALUE, "file_upload": fileobj},
-            )
+        self.client.set_cookie("user_input", "attack_cookie")
+        file_path = path.join(self.app.root_path, "..", "..", "data", "testfile.txt")
+        response = self.client.post(
+            "/dynamic-sources/?user_input={}&source={}".format(
+                self.ATTACK_VALUE, source
+            ),
+            {"user_input": self.ATTACK_VALUE},
+            headers={"Referer": "www.python.org"},
+            upload_files=[("file_upload", file_path)],
+            extra_environ={"REMOTE_ADDR": "localhost"},
+        )
 
         self.validate_source_finding(response, mocked, source)
 
@@ -272,7 +367,7 @@ class FlaskAssessTestMixin(object):
     def test_all_get_multidict(self, mocked, source):
         response = self.client.get(
             "/multidict-sources",
-            query_string={"user_input": self.ATTACK_VALUE, "source": source},
+            {"user_input": self.ATTACK_VALUE, "source": source},
             headers={"user_input": self.ATTACK_VALUE},
         )
 
@@ -284,10 +379,9 @@ class FlaskAssessTestMixin(object):
     @mocks.build_finding
     def test_all_post_multidict(self, mocked, source):
         response = self.client.post(
-            "/multidict-sources",
-            query_string={"source": source},
+            "/multidict-sources?source={}".format(source),
+            {"user_input": self.ATTACK_VALUE},
             headers={"user_input": self.ATTACK_VALUE},
-            data={"user_input": self.ATTACK_VALUE},
         )
 
         self.validate_source_finding(
@@ -296,19 +390,19 @@ class FlaskAssessTestMixin(object):
 
     def test_cookie_get(self):
         """Cookies shouldn't trigger xss, so we need a separate cookie source test"""
-        self.client.set_cookie("test", "user_input", "attack_cookie")
+        self.client.set_cookie("user_input", "attack_cookie")
         self.client.get("/cookie-source")
         validate_cookies_sources(self.request_context.activity.findings)
 
     def test_cookie_post(self):
         """Cookies shouldn't trigger xss, so we need a separate cookie source test"""
-        self.client.set_cookie("test", "user_input", "attack_cookie")
+        self.client.set_cookie("user_input", "attack_cookie")
         self.client.post("/cookie-source")
         validate_cookies_sources(self.request_context.activity.findings)
 
     @pytest.mark.parametrize(
         "route,source_name",
-        [("/header-source/", "header"), ("/header-key-source/", "header_key"),],
+        [("/header-source/", "header"), ("/header-key-source/", "header_key")],
     )
     @pytest.mark.parametrize("method_name", ["get", "post"])
     def test_non_xss_sources(self, method_name, route, source_name):
@@ -323,9 +417,9 @@ class FlaskAssessTestMixin(object):
         assert len(self.request_context.activity.findings) == 0
 
     @mocks.build_finding
-    def test_sqli_rule_get(self, mocked):
+    def test_sqli_sqlalchemy(self, mocked):
         param_val = "doesnt matter"
-        response = self.client.get("/sqli/?user_input=" + param_val)
+        response = self.client.get("/sqli/", {"user_input": param_val})
 
         query = "SELECT * FROM user WHERE user.email = 'doesnt matter'"
 
@@ -337,14 +431,40 @@ class FlaskAssessTestMixin(object):
         if six.PY3:
             assert_flask_sqli_finding_events(findings[0], "wsgi.environ")
 
+    @pytest.mark.parametrize(
+        "trigger,query_fmt",
+        [
+            ("sqlite3-execute", sqli.EXECUTE_QUERY_FMT),
+            ("sqlite3-executemany", sqli.EXECUTEMANY_QUERY_FMT),
+            ("sqlite3-executescript", sqli.EXECUTESCRIPT_QUERY_FMT,),
+        ],
+    )
+    @mocks.build_finding
+    def test_sqli(self, mocked, trigger, query_fmt):
+        user_input = "any value works"
+        response = self.client.get(
+            "/vulnpy/sqli/{}".format(trigger), {"user_input": user_input},
+        )
+
+        query = query_fmt.format(user_input)
+
+        validate_finding(
+            self.request_context.activity.findings,
+            response,
+            user_input,
+            query,
+            mocked,
+            "sql-injection",
+            1,
+        )
+
     @mocks.build_finding
     @pytest.mark.parametrize("with_kwarg", [False, True])
     def test_unvalidated_redirect(self, mocked, with_kwarg):
         redirect_route = "/cmdi"
         response = self.client.get(
-            "/unvalidated-redirect?user_input={}&with_kwarg={}".format(
-                redirect_route, with_kwarg
-            )
+            "/unvalidated-redirect",
+            {"user_input": redirect_route, "with_kwarg": with_kwarg},
         )
 
         validate_finding(
@@ -361,9 +481,8 @@ class FlaskAssessTestMixin(object):
     def test_trust_boundary_violation(self, setdefault):
         user_input = "hello"
         self.client.get(
-            "/trust-boundary-violation?user_input={}&setdefault={}".format(
-                user_input, setdefault
-            )
+            "/trust-boundary-violation",
+            {"user_input": user_input, "setdefault": setdefault},
         )
 
         assert len(self.request_context.activity.findings) == 1
@@ -374,9 +493,9 @@ class FlaskAssessTestMixin(object):
 
     @pytest.mark.parametrize("endpoint", ["exec", "eval", "compile"])
     def test_untrusted_code_exec(self, endpoint):
-        user_input = six.moves.urllib_parse.quote("1 + 2 + 3")
+        user_input = "1 + 2 + 3"
         self.client.get(
-            "/vulnpy/unsafe_code_exec/{}?user_input={}".format(endpoint, user_input)
+            "/vulnpy/unsafe_code_exec/{}".format(endpoint), {"user_input": user_input},
         )
 
         assert len(self.request_context.activity.findings) == 1
@@ -384,3 +503,51 @@ class FlaskAssessTestMixin(object):
             self.request_context.activity.findings[0].rule_id
             == u"unsafe-code-execution"
         )
+
+    @pytest.mark.parametrize(
+        "trigger", ["legacy-urlopen", "urlopen-str", "urlopen-obj"]
+    )
+    @pytest.mark.parametrize("safe", [False, True])
+    @mocks.build_finding
+    def test_ssrf_urllib(self, mocked, trigger, safe):
+        user_input = "not.a.url" if safe else "http://attacker.com/?q=foobar"
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": user_input},
+        )
+        assert response.status_code == 200
+        if not safe:
+            validate_ssrf_finding(trigger, self.request_context, mocked)
+        else:
+            assert not mocked.called
+            assert len(self.request_context.activity.findings) == 0
+
+    @pytest.mark.parametrize("trigger_class", ["httpconnection", "httpsconnection"])
+    @pytest.mark.parametrize(
+        "trigger_method", ["request-method", "putrequest-method", "init"]
+    )
+    @mocks.build_finding
+    def test_ssrf_httplib(self, mocked, trigger_method, trigger_class):
+        trigger = "-".join([trigger_class, trigger_method])
+        user_input = "www.attacker.com" if trigger_method == "init" else "DELETE"
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": user_input},
+        )
+        assert response.status_code == 200
+        validate_ssrf_finding(trigger, self.request_context, mocked)
+
+    @pytest.mark.parametrize("trigger_class", ["httpconnection", "httpsconnection"])
+    @pytest.mark.parametrize("trigger_method", ["request", "putrequest"])
+    @mocks.build_finding
+    def test_ssrf_httplib_safe(self, mocked, trigger_method, trigger_class):
+        """
+        HTTP*Connection.*request isn't vulnerable to SSRF via the "url" argument.
+        This is because it only takes a path / querystring, which isn't vulnerable
+        to ssrf.
+        """
+        trigger = "-".join([trigger_class, trigger_method, "url"])
+        response = self.client.get(
+            "/vulnpy/ssrf/{}".format(trigger), {"user_input": "/some/path"}
+        )
+        assert response.status_code == 200
+        assert not mocked.called
+        assert len(self.request_context.activity.findings) == 0
