@@ -4,6 +4,7 @@
 """
 Definitions of blueprints that can be used in flask test apps
 """
+import html
 import io
 import os
 from os import path
@@ -11,22 +12,73 @@ from os import path
 from flask import Blueprint, render_template, request, redirect
 from flask.sessions import SecureCookieSession
 import contrast
-
+from contrast.test.library_analysis import (
+    remove_sys_module_entries,
+    import_with_relative_imports,
+    import_namespace_package,
+    import_sample_package_onefile,
+    import_multiple_tlds,
+)
 
 APPTEST_DIR = path.join(path.dirname(contrast.__file__), "..")
 TEMPLATE_DIR = path.join(APPTEST_DIR, "templates", "flask")
 router = Blueprint("contrast", __name__, template_folder=TEMPLATE_DIR)
 
 
-@router.route("/raw-xss", methods=["GET", "POST"], strict_slashes=False)
-def raw_xss():
-    user_input = request.args.get("user_input")
-    result = "<p>User_input: {}</p>".format(user_input)
-    return result
+@router.route(
+    "/import_package_with_relative_imports", methods=["GET"], strict_slashes=False
+)
+def import_package_with_relative_imports():
+    rm_modules = request.args.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_with_relative_imports()
+
+    return ""
 
 
-@router.route("/sanitized-xss", methods=["GET", "POST"], strict_slashes=False)
-def sanitized_xss():
+@router.route("/import_namespace_package", methods=["GET"], strict_slashes=False)
+def import_sample_namespace_package():
+    # Deleting top level namespace modules breaks them in py2.
+    # Namespace name is cached in sys modules, but shows up
+    # as a builtin module in py2.
+    import_namespace_package()
+
+    return ""
+
+
+@router.route("/import_package_onefile", methods=["GET"], strict_slashes=False)
+def import_package_onefile():
+    rm_modules = request.args.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_sample_package_onefile()
+
+    return ""
+
+
+@router.route(
+    "/import_sample_dist_multiple_tlds", methods=["GET"], strict_slashes=False
+)
+def import_sample_dist_multiple_tlds():
+    rm_modules = request.args.get("rm_sys_mod_entries", None)
+
+    if rm_modules:
+        remove_sys_module_entries()
+
+    import_multiple_tlds()
+
+    return ""
+
+
+@router.route(
+    "/markupsafe-sanitized-xss", methods=["GET", "POST"], strict_slashes=False
+)
+def markupsafe_sanitized_xss():
     """
     This is a test for Markupsafe.escape as it gets called by the template engine.
     """
@@ -35,6 +87,16 @@ def sanitized_xss():
     return ret
 
 
+@router.route("/html-sanitized-xss", methods=["GET", "POST"], strict_slashes=False)
+def html_sanitized_xss():
+    """
+    This is a test for Markupsafe.escape as it gets called by the template engine.
+    """
+    user_input = request.args.get("user_input")
+    ret = html.escape(user_input)
+    return ret
+
+
 @router.route("/dynamic-sources", methods=["GET", "POST"], strict_slashes=False)
 def dynamic_sources():
     source = request.args.get("source", "")
