@@ -3,6 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import copy
 import mock
+import django
 
 import pytest
 from contrast.extern import six
@@ -137,8 +138,6 @@ def assert_django_sqli_finding_events(finding, source_class_name):
 
 
 def assert_xss_cookie_finding_events(finding):
-    import django
-
     legacy_django = django.__version__ < "1.11"
 
     assert len(finding.events) == 9
@@ -201,6 +200,11 @@ def assert_xss_cookie_finding_events(finding):
 
 
 def assert_subprocess_popen_finding_events(findings):
+    """
+    Verify each event in the finding. This requires some finagling because each
+    combination of django version + python version has a slightly different
+    sequence of events.
+    """
     events = findings[0].events
     assert len(events) == 9
 
@@ -217,7 +221,8 @@ def assert_subprocess_popen_finding_events(findings):
         ret_value="user_input=echo+attack",
     )
 
-    offset = 0 if six.PY3 else 1
+    offset = 1 if six.PY2 else 0
+    offset += 1 if django.VERSION[:2] == (1, 9) else 0
 
     check_event(
         events[1 + offset],
@@ -270,20 +275,23 @@ def assert_subprocess_popen_finding_events(findings):
         ret_value="echo+attack" if six.PY3 else "echo attack",
     )
 
-    check_event(
-        events[4 + offset],
-        event_type=TraceEvent.TYPE_PROPAGATION,
-        action=TraceEvent.Action.Value(
-            constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
-        ),
-        class_name="str" if six.PY3 else "urllib",
-        method_name="replace" if six.PY3 else "unquote",
-        source_types=[],
-        first_parent=events[3 + offset],
-        source="OBJ,P1" if six.PY3 else "P0,KWARG:s",
-        target=constants.RETURN,
-        ret_value="echo attack",
-    )
+    if django.VERSION[:2] == (1, 9):
+        offset -= 1
+    else:
+        check_event(
+            events[4 + offset],
+            event_type=TraceEvent.TYPE_PROPAGATION,
+            action=TraceEvent.Action.Value(
+                constants.ALL_TYPE + constants.TO_MARKER + constants.RETURN_KEY
+            ),
+            class_name="str" if six.PY3 else "urllib",
+            method_name="replace" if six.PY3 else "unquote",
+            source_types=[],
+            first_parent=events[3 + offset],
+            source="OBJ,P1" if six.PY3 else "P0,KWARG:s",
+            target=constants.RETURN,
+            ret_value="echo attack",
+        )
 
     check_event(
         events[5 + offset],
@@ -456,11 +464,6 @@ def build_assess_settings():
 
     settings = SettingsBuilder().build_assess()
 
-    # disable non dataflow rules
-    settings.application_settings.disabled_assess_rules.append("crypto-weak-randomness")
-    settings.application_settings.disabled_assess_rules.append("crypto-bad-mac")
-    settings.application_settings.disabled_assess_rules.append("crypto-bad-ciphers")
-
     settings.libraries = build_extra_libs()
 
     return settings
@@ -476,20 +479,3 @@ def current_routes_by_url(routes, url):
 
 def assert_routes_count(routes, routes_count):
     assert len(routes) == routes_count
-
-
-def assert_ssrf_finding(module, request_context, mocked):
-    assert mocked.called
-    assert mocked.call_args[0][1].name == "ssrf"
-
-    # This case results in multiple findings for reasons that are not entirely understood
-    num_findings = (
-        2
-        if module in ["urllib2_obj", "urllib2_str", "urllib.request_obj"]
-        or six.PY2
-        and module == "urllib"
-        else 1
-    )
-
-    assert len(request_context.activity.findings) == num_findings
-    assert request_context.activity.findings[0].rule_id == six.u("ssrf")
