@@ -4,6 +4,7 @@
 import contrast
 
 from contrast.agent.policy.constants import CURRENT_FINDING_VERSION
+from contrast.extern import six
 
 # These request part values must match the TYPE parameter for source nodes in policy.json, which are
 # a best effort at translating the types in this document:
@@ -28,6 +29,16 @@ SOURCE_OPTIONS = {
 }
 
 
+def validate_finding_in_context(request_context, rule_id, nondataflow=False):
+    assert len(request_context.activity.findings) == 1
+    finding = request_context.activity.findings[0]
+    assert finding.rule_id == rule_id
+    assert finding.version == CURRENT_FINDING_VERSION
+    assert len(finding.routes) == 1
+    if nondataflow:
+        assert len(finding.events) == 1
+
+
 def validate_finding(
     findings,
     response,
@@ -179,3 +190,22 @@ def param_is_tracked(param_val):
         if props.origin == param_val:
             return True
     return False
+
+
+def validate_ssrf_finding(trigger, request_context, mocked):
+    assert mocked.called
+    assert mocked.call_args[0][1].name == "ssrf"
+
+
+def validate_ssrf_finding_no_mock(trigger, request_context):
+    # This case results in multiple findings for reasons that are not entirely understood
+    num_findings = (
+        2
+        if trigger == "urlopen-obj"
+        or six.PY2
+        and trigger in ["legacy-urlopen", "urlopen-str"]
+        else 1
+    )
+
+    assert len(request_context.activity.findings) == num_findings
+    assert request_context.activity.findings[0].rule_id == six.u("ssrf")
