@@ -15,7 +15,7 @@ from contrast.api.settings_pb2 import (
 
 from contrast.configuration import AgentConfig
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
