@@ -4,9 +4,8 @@
 from io import IOBase
 
 from contrast.extern import six
-from contrast.utils.decorators import fail_quietly
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -38,11 +37,11 @@ def is_filelike(value):
     return isinstance(value, IOBase)
 
 
-@fail_quietly(
-    "failed to get object __len__, defaulting to 0", return_value=0,
-)
-def safe_obj_length(value):
-    return len(value) if value is not None else 0
+def len_or_zero(value):
+    try:
+        return len(value)
+    except Exception:
+        return 0
 
 
 def safe_iterator(it):
