@@ -12,7 +12,7 @@ from contrast.agent.assess.policy.source_policy import apply_stream_source
 from contrast.agent.settings_state import SettingsState
 from contrast.utils.decorators import fail_safely
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
@@ -181,9 +181,10 @@ def _instrument_source_stream_method(stream, method_name):
     """
     orig_method = getattr(stream, method_name, None)
     if orig_method is None:
-        raise ValueError(
-            "source stream missing expected attribute: {}".format(method_name)
+        logger.debug(
+            "WARNING: source stream missing expected attribute: %s", method_name
         )
+        return
     new_method = _build_patch(orig_method)
     setattr(stream, method_name, new_method)
 
