@@ -9,7 +9,7 @@ from contrast.agent.assess.utils import cs__tracked
 from contrast.utils.decorators import fail_quietly
 from contrast.utils.assess.duck_utils import safe_iterator
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
