@@ -1,19 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.api.dtm_pb2 import ArchitectureComponent, LibraryUsageUpdate
-
-
-def append_libraries(activity, settings):
-    if not settings.config.get("inventory.enable", True):
-        return
-
-    for library in settings.libraries:
-        usage = LibraryUsageUpdate()
-        usage.hash_code = library.hash_code
-        usage.count = library.used_class_count
-
-        activity.library_usages[library.hash_code].CopyFrom(usage)
+from contrast.api.dtm_pb2 import ArchitectureComponent
 
 
 def append_db(activity, db_info):
