@@ -2,21 +2,19 @@
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
-from logging import (
-    StreamHandler,
-    FileHandler,
-    Formatter,
-    INFO,
-    Filter,
-    getLogger,
-    getLevelName,
+import logging
+
+from contrast.utils.loggers.structlog import init_structlog
+
+from contrast.extern import structlog
+
+from . import (
+    DEFAULT_LOG_LEVEL,
+    DEFAULT_LOG_PATH,
+    DEFAULT_PROGNAME,
+    LOGGER_NAME,
 )
 
-
-DEFAULT_LOG_PATH = "contrast-agent.log"
-DEFAULT_LOG_LEVEL = "INFO"
-DEFAULT_PROGNAME = "Contrast Security"
-LOGGER_NAME = "contrast"
 STDOUT = "STDOUT"
 STDERR = "STDERR"
 
@@ -31,17 +29,21 @@ def setup_basic_agent_logger():
     The logger created here is expected to be overridden with config values
     provided later on in the middleware creation cycle.
     """
-    logger = getLogger("contrast")
-    logger.addHandler(StreamHandler(sys.stdout))
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.addHandler(logging.StreamHandler(sys.stdout))
     _set_handler(logger, "STDOUT", DEFAULT_PROGNAME)
-    logger.setLevel(INFO)
+    logger.setLevel(logging.INFO)
 
-    return logger
+    init_structlog()
+
+    return structlog.getLogger(LOGGER_NAME)
 
 
 def setup_agent_logger(config):
     """
     Initialize the agent logger with configurations.
+    :param config: instance of AgentConfig or dict
+    :return: None
     """
     config = config if config else {}
     # the or handles the case of empty string
@@ -50,17 +52,19 @@ def setup_agent_logger(config):
         config.get("agent.logger.level", DEFAULT_LOG_LEVEL).upper() or DEFAULT_LOG_LEVEL
     )
 
-    logger = getLogger(LOGGER_NAME)
+    logger = logging.getLogger(LOGGER_NAME)
     _set_logger_info(logger, config, path, level)
     _lock_logger(logger, config)
 
     # print so it shows up in STDOUT
     print(
         "Contrast Agent Logger Initialized: {} : {}".format(
-            getLevelName(logger.level), path
+            logging.getLevelName(logger.level), path
         )
     )  # pylint: disable=superfluous-parens
 
+    init_structlog()
+
 
 def reset_agent_logger(log_path, log_level):
     """
@@ -70,12 +74,18 @@ def reset_agent_logger(log_path, log_level):
     as this is what we set when we initialize the logger.
 
     Also note that progname is never reset so we use the one already set to the logger.
+
+    :return: Bool if any logger value is reset
     """
-    logger = getLogger(LOGGER_NAME)
+    logger = logging.getLogger(LOGGER_NAME)
 
     if not hasattr(logger, "lock_path") or not hasattr(logger, "lock_level"):
-        logger.debug("Will not reset agent logger without set lock_attr values.")
-        return
+        structlog.getLogger(LOGGER_NAME).debug(
+            "Will not reset agent logger without set lock_attr values."
+        )
+        return False
+
+    is_reset = False
 
     if not logger.lock_path and log_path:
         current_handler = logger.handlers[0]
@@ -83,11 +93,15 @@ def reset_agent_logger(log_path, log_level):
         _set_handler(logger, log_path, progname)
         # print so it shows up in STDOUT
         print("Contrast Agent Logger updated path to ", log_path)
+        is_reset = True
 
     if not logger.lock_level and log_level:
         _set_level(logger, log_level)
         # print so it shows up in STDOUT
         print("Contrast Agent Logger updated level to ", log_level)
+        is_reset = True
+
+    return is_reset
 
 
 def _set_logger_info(logger, config, path, level):
@@ -107,16 +121,9 @@ def _set_handler(logger, path, progname):
     CONTRAST-39746 defined the datetime format as ISO_8601. The one here is
     without ms as the logger doesn't natively support both ms and time zone at this time.
     """
-    formatter = Formatter(
-        "%(asctime)s [%(progname)s] (%(filename)s:%(funcName)s:%(lineno)d)"
-        " - %(levelname)s - %(message)s",
-        "%Y-%m-%dT%H:%M:%S%z",
-    )
-
     handler = _get_handler(path)
     program_filter = AgentFilter(progname=progname)
     handler.addFilter(program_filter)
-    handler.setFormatter(formatter)
 
     # empty all handlers so there is only one logging handler with this config
     logger.handlers = []
@@ -125,15 +132,15 @@ def _set_handler(logger, path, progname):
 
 def _get_handler(path):
     if path == STDOUT:
-        handler = StreamHandler(sys.stdout)
+        handler = logging.StreamHandler(sys.stdout)
     elif path == STDERR:
-        handler = StreamHandler(sys.stderr)
+        handler = logging.StreamHandler(sys.stderr)
     else:
         try:
-            handler = FileHandler(path)
+            handler = logging.FileHandler(path)
         except Exception:
             # path could be '' or None
-            handler = StreamHandler()
+            handler = logging.StreamHandler()
     return handler
 
 
@@ -167,7 +174,7 @@ def _lock_logger_attr(logger, logger_attr, config):
     setattr(logger, "lock_{}".format(logger_attr), bool(attr_value))
 
 
-class AgentFilter(Filter):
+class AgentFilter(logging.Filter):
     def __init__(self, progname=None):
         self.progname = progname
         super(AgentFilter, self).__init__()
