@@ -15,7 +15,7 @@ from contrast.utils.ignored_modules import (
 )
 from contrast.utils.object_share import ObjectShare
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
